#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.UserGroup import UserGroup
from icinga2confgen.Notification.NotificationCommand import NotificationCommand
from icinga2confgen.Notification.TimePeriod import TimePeriod
from icinga2confgen.User.User import User
from icinga2confgen.ValueChecker import ValueChecker
from icinga2confgen.ValueMapper import ValueMapper


class Notification:

    def __init__(self, id):
        self.__id = id
        self.__interval = '1h'
        self.__command = self.get_command_config()
        self.__time_period = None
        self.__escalation = None
        self.__users = []
        self.__user_groups = []

        self.__allowed_host_types = ['DowntimeStart', 'DowntimeEnd', 'DowntimeRemoved', 'Custom', 'Acknowledgement',
                                     'Problem', 'Recovery', 'FlappingStart', 'FlappingEnd']
        self.__host_types = self.__allowed_host_types
        self.__allowed_host_states = ['Up', 'Down']
        self.__host_states = self.__allowed_host_states

        self.__allowed_service_types = ['DowntimeStart', 'DowntimeEnd', 'DowntimeRemoved', 'Custom', 'Acknowledgement',
                                        'Problem', 'Recovery', 'FlappingStart', 'FlappingEnd']
        self.__service_types = self.__allowed_service_types
        self.__allowed_service_states = ['Warning', 'Critical', 'Unknown', 'OK']
        self.__service_states = self.__allowed_service_states

    def get_command_config(self):
        raise Exception('You must override get_command_config')

    @staticmethod
    def create(id, force_create=False):
        raise Exception('Cannot create Notification, use child classes instead')

    def get_id(self):
        return self.__id

    def set_interval(self, interval):
        ValueChecker.is_string(interval)
        self.__interval = interval
        return self

    def get_interval(self):
        return self.__interval

    def set_command(self, command):
        if isinstance(command, NotificationCommand):
            self.__command = command.get_id()
        elif isinstance(command, str):
            command = ConfigBuilder.get_notification_command(command)
            if None is command:
                raise Exception('NotificationCommand does not exist yet!')
            self.__command = command.get_id()
        return self

    def get_command(self):
        return self.__command

    def set_time_period(self, time_period):
        if isinstance(time_period, TimePeriod):
            self.__time_period = time_period.get_id()

        elif isinstance(time_period, str):
            if None is ConfigBuilder.get_time_period(time_period):
                raise Exception('Time Period does not exist yet!')
            self.__time_period = time_period
        else:
            raise Exception('Can only add Time Period or id of Time Period!')
        return self

    def get_time_period(self):
        return self.__time_period

    def set_escalation(self, begin, end):
        ValueChecker.is_string(begin)
        ValueChecker.is_string(end)
        self.__escalation = (begin, end)

        return self

    def get_escalation(self):
        return self.__escalation

    def set_host_types(self, types):
        for type in types:
            if type not in self.__allowed_host_types:
                raise Exception('Type ' + type + ' is not allowed for host')
        self.__host_types = types
        return self

    def get_host_types(self):
        return self.__host_types

    def set_host_states(self, states):
        for state in states:
            if state not in self.__allowed_host_states:
                raise Exception('State ' + state + ' is not allowed for host')
        self.__host_states = states
        return self

    def get_host_states(self):
        return self.__host_states

    def set_service_types(self, types):
        for type in types:
            if type not in self.__allowed_service_types:
                raise Exception('Type ' + type + ' is not allowed for service')
        self.__service_types = types
        return self

    def get_service_types(self):
        return self.__service_types

    def set_service_states(self, states):
        for state in states:
            if state not in self.__allowed_service_states:
                raise Exception('State ' + state + ' is not allowed for service')
        self.__service_states = states
        return self

    def get_service_states(self):
        return self.__service_states

    def add_user(self, user):
        if isinstance(user, User):
            if user not in self.__users:
                self.__users.append(user)

        elif isinstance(user, str):
            user = ConfigBuilder.get_user(user)
            if None is user:
                raise Exception('User does not exist yet!')
            self.add_user(user)
        else:
            raise Exception('Can only add User or id of User!')
        return self

    def remove_user(self, user):
        if isinstance(user, User):
            self.__users.remove(user)

        elif isinstance(user, str):
            user = ConfigBuilder.get_user(user)
            self.__users.remove(user)

        return self

    def get_users(self):
        return self.__users

    def add_user_group(self, user_group):
        if isinstance(user_group, UserGroup):
            if user_group not in self.__user_groups:
                self.__user_groups.append(user_group)

        elif isinstance(user_group, str):
            user_group = ConfigBuilder.get_usergroup(user_group)
            if None is user_group:
                raise Exception('UserGroup does not exist yet!')
            self.add_user_group(user_group)
        else:
            raise Exception('Can only add UserGroup or id of UserGroup!')
        return self

    def remove_user_group(self, user_group):
        if isinstance(user_group, UserGroup):
            self.__user_groups.remove(user_group)

        elif isinstance(user_group, str):
            user_group = ConfigBuilder.get_usergroup(user_group)
            self.__user_groups.remove(user_group)

        return self

    def get_user_groups(self):
        return self.__user_groups

    def validate(self):
        if None is self.__command:
            raise Exception('You have to set a Command for Notification!')

        if 0 == len(self.__users) and 0 == len(self.__user_groups):
            raise Exception('You have to add a user or user group for Notification ' + self.__id)

    def get_config(self):
        self.validate()

        config = 'template Notification "notification_template_host_' + self.__id + '" {\n'
        config += '  interval = ' + self.__interval + '\n'

        if None is not self.__escalation:
            config += '  times = {\n'
            config += '    begin = ' + self.__escalation[0] + '\n'
            config += '    end = ' + self.__escalation[1] + '\n'
            config += '  }\n'

        config += ValueMapper.parse_var('command', self.__command, value_prefix='command_host_')
        config += ValueMapper.parse_var('period', self.__time_period, value_prefix='time_period_')
        config += ValueMapper.parse_var('user_groups', self.__user_groups, value_prefix='usergroup_')
        config += ValueMapper.parse_var('users', self.__users, value_prefix='user_')
        config += ValueMapper.parse_var('types', self.__host_types)
        config += ValueMapper.parse_var('states', self.__host_states)
        config += '}\n'
        config += 'template Notification "notification_template_service_' + self.__id + '" {\n'
        config += '  interval = ' + self.__interval + '\n'

        if None is not self.__escalation:
            config += '  times = {\n'
            config += '    begin = ' + self.__escalation[0] + '\n'
            config += '    end = ' + self.__escalation[1] + '\n'
            config += '  }\n'

        config += ValueMapper.parse_var('command', self.__command, value_prefix='command_service_')
        config += ValueMapper.parse_var('period', self.__time_period, value_prefix='time_period_')
        config += ValueMapper.parse_var('user_groups', self.__user_groups, value_prefix='usergroup_')
        config += ValueMapper.parse_var('users', self.__users, value_prefix='user_')
        config += ValueMapper.parse_var('types', self.__service_types)
        config += ValueMapper.parse_var('states', self.__service_states)
        config += '}\n'

        return config

    def apply_for_all_emails(self):

        config = ''
        all_users = ConfigBuilder.get_instance('users')
        for group in self.get_user_groups():
            added_user = []
            for user in all_users:
                if user in added_user:
                    continue

                added_user.append(user)
                added_emails = []
                groups_of_user = user.get_groups()
                if group in groups_of_user:
                    for email in user.get_email():
                        if email in added_emails:
                            continue

                        added_emails.append(email)
                        cemail = ValueMapper.canonicalize_for_id(email.replace('@', '_'))
                        for type in ['Service', 'Host']:
                            notification_id = 'notification_' + type.lower() + '_' + self.get_id() + '_' \
                                              + user.get_id() + '_' + cemail
                            config += 'apply Notification "' + notification_id + '" to ' + type + ' {\n'
                            config += '  import "notification_template_' + type.lower() + '_' \
                                      + Notification.get_id(self) + '"\n'
                            config += '  vars.email = "' + email + '"\n'
                            config += '  assign where "notification_' + self.get_id() + '" in ' \
                                      + type.lower() + '.vars.notification\n'
                            config += '}\n'

        return config



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.
from icinga2confgen.Checks.MonitoringPlugins.CheckPing4 import CheckPing4
from icinga2confgen.Checks.MonitoringPlugins.CheckSSH import CheckSSH
from icinga2confgen.ValueChecker import ValueChecker


class DefaultRemoteChecks:

    def __init__(self, servers=[], checkserver=[], notifications=[]):
        self.__checkserver = checkserver
        self.__notifications = notifications
        self.__servers = servers
        self.__check_ping = True
        self.__check_ssh = True
        self.__check_ssh_port = 22

    def check_ping(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_ping = enabled

        return self

    def is_checking_ping(self):
        return self.__check_ping

    def check_ssh(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_ssh = enabled

        return self

    def is_checking_ssh(self):
        return self.__check_ssh

    def check_ssh_port(self, port):
        ValueChecker.is_number(port)
        self.__check_ssh_port = port

        return self

    def is_checking_ssh_port(self):
        return self.__check_ssh_port

    def apply_check(self, check):
        for notification in self.__notifications:
            check.add_notification(notification)

        for checkserver in self.__checkserver:
            checkserver.add_check(check)

    def apply(self):
        for server in self.__servers:
            base_id = 'remote_checks_' + server.get_id()
            ipv4 = server.get_ipv4()
            ipv6 = server.get_ipv6()

            if True is self.__check_ping:
                if None is not ipv4:
                    check = CheckPing4.create('ping4_' + base_id)
                    check.set_address(ipv4) \
                        .set_display_name(check.get_display_name() + ' ' + server.get_display_name())
                    self.apply_check(check)
                if None is not ipv6:
                    check = CheckPing4.create('ping6_' + base_id)
                    check.set_address(ipv6) \
                        .set_display_name(check.get_display_name() + ' ' + server.get_display_name())
                    self.apply_check(check)

            if True is self.__check_ssh:
                if None is not ipv4:
                    check = CheckSSH.create('ssh_ipv4_' + base_id)
                    check.set_hostname(ipv4) \
                        .set_port(self.__check_ssh_port) \
                        .set_display_name(check.get_display_name() + ' ' + server.get_display_name())
                    self.apply_check(check)

                if None is not ipv6:
                    check = CheckSSH.create('ssh_ipv4_' + base_id)
                    check.set_hostname(ipv6) \
                        .set_port(self.__check_ssh_port) \
                        .set_display_name(check.get_display_name() + ' ' + server.get_display_name())
                    self.apply_check(check)



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.MonitoringPlugins.NTPPeerCommand import NTPPeerCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckNTPPeer(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckNTPPeer', 'ntp_peer')
        self.__force_ipv4 = False
        self.__force_ipv6 = False
        self.__ntp_server = None
        self.__ntp_server_port = 123
        self.__quiet = None
        self.__warning = None
        self.__critical = None
        self.__swarn = None
        self.__scrit = None
        self.__jwarn = None
        self.__jcrit = None
        self.__twarn = None
        self.__tcrit = None
        self.__timeout = 10
        self.set_check_interval('5m')
        self.add_service_group(ServiceGroup.create('ntp'))
        self.add_service_group(ServiceGroup.create('network'))

    def set_warning(self, seconds):
        ValueChecker.is_number(seconds)
        self.__warning = seconds
        return self

    def get_warning(self):
        return self.__warning

    def set_critical(self, seconds):
        ValueChecker.is_number(seconds)
        self.__critical = seconds
        return self

    def get_critical(self):
        return self.__critical

    def set_swarn(self, seconds):
        ValueChecker.is_number(seconds)
        self.__swarn = seconds
        return self

    def get_swarn(self):
        return self.__swarn

    def set_scrit(self, seconds):
        ValueChecker.is_number(seconds)
        self.__scrit = seconds
        return self

    def get_scrit(self):
        return self.__scrit

    def set_jwarn(self, seconds):
        ValueChecker.is_number(seconds)
        self.__jwarn = seconds
        return self

    def get_jwarn(self):
        return self.__jwarn

    def set_jcrit(self, seconds):
        ValueChecker.is_number(seconds)
        self.__jcrit = seconds
        return self

    def get_jcrit(self):
        return self.__jcrit

    def set_twarn(self, seconds):
        ValueChecker.is_number(seconds)
        self.__twarn = seconds
        return self

    def get_twarn(self):
        return self.__twarn

    def set_tcrit(self, seconds):
        ValueChecker.is_number(seconds)
        self.__tcrit = seconds
        return self

    def get_tcrit(self):
        return self.__tcrit

    def set_timeout(self, seconds):
        ValueChecker.is_number(seconds)
        self.__timeout = seconds
        return self

    def get_timeout(self):
        return self.__timeout

    def set_force_ipv4(self, seconds):
        ValueChecker.is_number(seconds)
        self.__force_ipv4 = seconds
        return self

    def get_force_ipv4(self):
        return self.__force_ipv4

    def set_force_ipv6(self, seconds):
        ValueChecker.is_number(seconds)
        self.__force_ipv6 = seconds
        return self

    def get_force_ipv6(self):
        return self.__force_ipv6

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckNTPPeer(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('ntp_peer'):
            NTPPeerCommand.create('ntp_peer')

        return check

    def validate(self):
        if None is self.__ntp_server:
            raise Exception('You have to specify a ntp server for ' + self.get_id())



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Utils.DefaultNames import get_default_group_name
from icinga2confgen.ValueChecker import ValueChecker


class Group:

    def __init__(self, id, type):
        self.__id = id
        self.__type = type
        self.__display_name = get_default_group_name(id)

    def set_display_name(self, name):
        ValueChecker.is_string(name)
        self.__display_name = name
        return self

    def get_display_name(self):
        return self.__display_name

    def get_id(self):
        return self.__id

    def get_config(self):
        config = 'object ' + self.__type.capitalize() + 'Group "' + self.__type + 'group_' + self.get_id() + '" {\n'
        if None is not self.__display_name:
            config += '  display_name = "' + self.__display_name + '"\n'
        config += '  assign where "' + self.__type + 'group_' + self.get_id() + '" in ' + self.__type + '.groups\n'
        config += '}\n'

        return config



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckPing(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckPing', 'ping')
        self.__warning_percent_lost = 5
        self.__warning_average_time = 100
        self.__critical_percent_lost = 10
        self.__critical_average_time = 250
        self.__timeout = 10
        self.__packets = 4
        self.__address = None
        self.add_service_group(ServiceGroup.create('ping'))
        self.add_service_group(ServiceGroup.create('network'))

    def set_warning_percent_lost(self, threshold):
        ValueChecker.is_number(threshold)
        self.__warning_percent_lost = threshold

    def get_warning_percent_lost(self):
        return self.__warning_percent_lost

    def set_warning_average_time(self, time):
        ValueChecker.is_number(time)
        self.__warning_average_time = time

    def get_warning_average_time(self):
        return self.__warning_average_time

    def set_critical_percent_lost(self, threshold):
        ValueChecker.is_number(threshold)
        self.__critical_percent_lost = threshold

    def get_critical_percent_lost(self):
        return self.__critical_percent_lost

    def set_critical_average_time(self, time):
        ValueChecker.is_number(time)
        self.__critical_average_time = time

    def get_critical_average_time(self):
        return self.__critical_average_time

    def set_timeout(self, timeout):
        ValueChecker.is_number(timeout)
        self.__timeout = timeout

    def get_timeout(self):
        return self.__timeout

    def set_packets(self, packets):
        ValueChecker.is_number(packets)
        self.__packets = packets

    def get_packets(self):
        return self.__packets

    def set_address(self, address):
        ValueChecker.is_string(address)
        self.__address = address
        return self

    def get_address(self):
        return self.__address

    def get_config(self):
        raise Exception(
            'You can\'t use CheckPing for your configuration directly. Please use CheckPing4 or CheckPing6 instead')

    def validate(self):
        if None is self.__address:
            raise Exception('You have to specify an address for ' + self.get_id())



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.MonitoringPlugins.SSHCommand import SSHCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckSSH(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckSSH', 'ssh')
        self.__hostname = None
        self.__port = None
        self.__timeout = None
        self.__remote_version = None
        self.__remote_protocol = None
        self.__force_ipv4 = None
        self.__force_ipv6 = None
        self.add_service_group(ServiceGroup.create('sshd'))

    def set_hostname(self, hostname):
        ValueChecker.is_string(hostname)
        self.__hostname = hostname
        return self

    def get_hostname(self):
        return self.__hostname

    def set_port(self, port):
        ValueChecker.is_number(port)
        self.__port = port
        return self

    def get_port(self):
        return self.__port

    def set_timeout(self, timeout):
        ValueChecker.is_number(timeout)
        self.__timeout = timeout
        return self

    def get_timeout(self):
        return self.__timeout

    def set_remote_version(self, remote_version):
        ValueChecker.is_string(remote_version)
        self.__remote_version = remote_version
        return self

    def get_remote_version(self):
        return self.__remote_version

    def set_remote_protocol(self, remote_protocol):
        ValueChecker.is_string(remote_protocol)
        self.__remote_protocol = remote_protocol
        return self

    def get_remote_protocol(self):
        return self.__remote_protocol

    def set_force_ipv4(self, enabled):
        ValueChecker.is_number(enabled)
        self.__force_ipv4 = enabled
        return self

    def get_force_ipv4(self):
        return self.__force_ipv4

    def set_force_ipv6(self, enabled):
        ValueChecker.is_number(enabled)
        self.__force_ipv6 = enabled
        return self

    def get_force_ipv6(self):
        return self.__force_ipv6

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckSSH(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('ssh'):
            SSHCommand.create('ssh')

        return check

    def validate(self):
        if None is self.__hostname:
            raise Exception('You have to specify a hostname for ' + self.get_id())



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.MonitoringPlugins.SNMPCommand import SNMPCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckSNMP(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckSNMP', 'snmp')
        self.__over_ipv4 = False
        self.__over_ipv6 = False
        self.__host = None
        self.__port = 161
        self.__snmp_getnext = False
        self.__protocol = None
        self.__context = None
        self.__seclevel = None
        self.__authproto = None
        self.__privproto = None
        self.__community = None
        self.__username = None
        self.__authpassword = None
        self.__privpassword = None
        self.__oids = None
        self.__delimiter = None
        self.__warning = None
        self.__critical = None
        self.__rate = False
        self.__rate_multiplier = None
        self.__offset = None
        self.__string = None
        self.__ereg = None
        self.__invert = False
        self.__label = None
        self.__units = None
        self.__output_delimiter = None
        self.__timeout = 10
        self.__retries = 2
        self.__perf_oids = False
        self.add_service_group(ServiceGroup.create('snmp'))
        self.add_service_group(ServiceGroup.create('network'))

    def set_over_ipv4(self, over_ipv4):
        ValueChecker.is_bool(over_ipv4)
        self.__over_ipv4 = over_ipv4
        return self

    def get_over_ipv4(self):
        return self.__over_ipv4

    def set_over_ipv6(self, over_ipv6):
        ValueChecker.is_bool(over_ipv6)
        self.__over_ipv6 = over_ipv6
        return self

    def get_over_ipv6(self):
        return self.__over_ipv6

    def set_host(self, host):
        ValueChecker.is_string(host)
        self.__host = host
        return self

    def get_host(self):
        return self.__host

    def set_port(self, port):
        ValueChecker.is_string(port)
        self.__port = port
        return self

    def get_port(self):
        return self.__port

    def set_snmp_getnext(self, snmp_getnext):
        ValueChecker.is_bool(snmp_getnext)
        self.__snmp_getnext = snmp_getnext
        return self

    def get_snmp_getnext(self):
        return self.__snmp_getnext

    def set_protocol(self, protocol):
        ValueChecker.is_string(protocol)
        self.__protocol = protocol
        return self

    def get_protocol(self):
        return self.__protocol

    def set_context(self, context):
        ValueChecker.is_string(context)
        self.__context = context
        return self

    def get_context(self):
        return self.__context

    def set_seclevel(self, seclevel):
        ValueChecker.is_string(seclevel)
        self.__seclevel = seclevel
        return self

    def get_seclevel(self):
        return self.__seclevel

    def set_authproto(self, authproto):
        ValueChecker.is_string(authproto)
        self.__authproto = authproto
        return self

    def get_authproto(self):
        return self.__authproto

    def set_privproto(self, privproto):
        ValueChecker.is_string(privproto)
        self.__privproto = privproto
        return self

    def get_privproto(self):
        return self.__privproto

    def set_community(self, community):
        ValueChecker.is_string(community)
        self.__community = community
        return self

    def get_community(self):
        return self.__community

    def set_username(self, username):
        ValueChecker.is_string(username)
        self.__username = username
        return self

    def get_username(self):
        return self.__username

    def set_authpassword(self, authpassword):
        ValueChecker.is_string(authpassword)
        self.__authpassword = authpassword
        return self

    def get_authpassword(self):
        return self.__authpassword

    def set_privpassword(self, privpassword):
        ValueChecker.is_string(privpassword)
        self.__privpassword = privpassword
        return self

    def get_privpassword(self):
        return self.__privpassword

    def set_oids(self, oids):
        ValueChecker.is_string(oids)
        self.__oids = oids
        return self

    def get_oids(self):
        return self.__oids

    def set_delimiter(self, delimiter):
        ValueChecker.is_string(delimiter)
        self.__delimiter = delimiter
        return self

    def get_delimiter(self):
        return self.__delimiter

    def set_warning(self, warning):
        ValueChecker.is_string(warning)
        self.__warning = warning
        return self

    def get_warning(self):
        return self.__warning

    def set_critical(self, critical):
        ValueChecker.is_string(critical)
        self.__critical = critical
        return self

    def get_critical(self):
        return self.__critical

    def set_rate(self, rate):
        ValueChecker.is_bool(rate)
        self.__rate = rate
        return self

    def get_rate(self):
        return self.__rate

    def set_rate_multiplier(self, rate_multiplier):
        ValueChecker.is_number(rate_multiplier)
        self.__rate_multiplier = rate_multiplier
        return self

    def get_rate_multiplier(self):
        return self.__rate_multiplier

    def set_offset(self, offset):
        ValueChecker.is_bool(offset)
        self.__offset = offset
        return self

    def get_offset(self):
        return self.__offset

    def set_string(self, string):
        ValueChecker.is_string(string)
        self.__string = string
        return self

    def get_string(self):
        return self.__string

    def set_ereg(self, ereg):
        ValueChecker.is_string(ereg)
        self.__ereg = ereg
        return self

    def get_ereg(self):
        return self.__ereg

    def set_invert(self, invert):
        ValueChecker.is_bool(invert)
        self.__invert = invert
        return self

    def get_invert(self):
        return self.__invert

    def set_label(self, label):
        ValueChecker.is_string(label)
        self.__label = label
        return self

    def get_label(self):
        return self.__label

    def set_units(self, units):
        ValueChecker.is_string(units)
        self.__units = units
        return self

    def get_units(self):
        return self.__units

    def set_output_delimiter(self, output_delimiter):
        ValueChecker.is_string(output_delimiter)
        self.__output_delimiter = output_delimiter
        return self

    def get_output_delimiter(self):
        return self.__output_delimiter

    def set_timeout(self, timeout):
        ValueChecker.is_number(timeout)
        self.__timeout = timeout
        return self

    def get_timeout(self):
        return self.__timeout

    def set_retries(self, retries):
        ValueChecker.is_number(retries)
        self.__retries = retries
        return self

    def get_retries(self):
        return self.__retries

    def set_perf_oids(self, perf_oids):
        ValueChecker.is_bool(perf_oids)
        self.__perf_oids = perf_oids
        return self

    def get_perf_oids(self):
        return self.__perf_oids

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckSNMP(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('snmp'):
            SNMPCommand.create('snmp')

        return check

    def validate(self):
        if None is self.__host:
            raise Exception('You have to specify a host for ' + self.get_id())
        if None is self.__oids:
            raise Exception('You have to specify a oids for ' + self.get_id())



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.


class Command:

    def __init__(self, id):
        self.__id = id

    def get_id(self):
        return self.__id

    def get_command(self):
        raise Exception("get_command must return command name")

    def get_arguments(self):
        raise Exception("get_arguments must return arguments")

    def get_config(self):
        config = self.get_config_local()
        config += self.get_config_ssh()

        return config

    def get_command_definition(self):
        return '[ "$plugin_dir$" + "/' + self.get_command() + '"]'

    def get_config_local(self):
        config = 'object CheckCommand "command_' + self.get_id() + '_local" {\n'
        config += '  command = ' + self.get_command_definition() + '\n'
        config += '  arguments = ' + self.get_arguments() + '\n'
        config += '}\n'

        return config

    def get_config_ssh(self):
        config = 'object CheckCommand "command_' + self.get_id() + '_ssh" {\n'
        config += '  vars.realcmd = ' + self.get_command_definition() + '\n'
        config += '  vars.realargs = ' + self.get_arguments() + '\n'
        config += """  command = [ "$command_overssh_plugin_dir$" + "/check_by_ssh"]
  arguments = {
    "-i" = "$command_overssh_identityfile$"
    "-l" = "$command_overssh_user$"
    "-p" = "$command_overssh_port$"
    "-H" = "$command_overssh_host$"
    "--timeout" = "$command_overssh_timeout$"
    "-C" = {{
      var command = macro("$realcmd$")
      var arguments = macro("$realargs$")
      if (typeof(command) == String && !arguments) {
        return command
      }
      var escaped_args = []
      for (arg in resolve_arguments(command, arguments)) {
        escaped_args.add(escape_shell_arg(arg))
      }
      return escaped_args.join(" ")
    }}
  }
}
"""
        return config



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.MonitoringPlugins.DiskCommand import DiskCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckDisk(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckDisk', 'disk')
        self.__warning = '20%'
        self.__critical = '10%'
        self.__inode_warning = 20
        self.__inode_critical = 10
        self.__combined_thresholds = None
        self.__path = None
        self.__partition = None
        self.__exclude_device = None
        self.__clear_thresholds = None
        self.__exact_match = None
        self.__errors_only = None
        self.__freespace_ignore_reserved = None
        self.__group = None
        self.__local = None
        self.__skip_fake_fs = None
        self.__inode_perfdata = None
        self.__stat_remote_fs = None
        self.__display_mountpoint = None
        self.__all = None
        self.__eregi_path = None
        self.__eregi_partition = None
        self.__ignore_eregi_path = None
        self.__ignore_eregi_partition = None
        self.__ereg_path = None
        self.__ereg_partition = None
        self.__ignore_ereg_path = None
        self.__ignore_ereg_partition = None
        self.__timeout = None
        self.__units = None
        self.__exclude_type = None
        self.__include_type = None
        self.__newlines = None
        self.set_check_interval('30m')
        self.add_service_group(ServiceGroup.create('disk'))

    def set_warning_units(self, number):
        ValueChecker.is_number(number)
        self.__warning = str(number)
        return self

    def get_warning_units(self):
        return self.__warning

    def set_warning_percent(self, number):
        ValueChecker.is_number(number)
        self.__warning = str(number) + '%'
        return self

    def get_warning_percent(self):
        return self.__warning

    def set_critical_units(self, number):
        ValueChecker.is_number(number)
        self.__critical = str(number)
        return self

    def get_critical_units(self):
        return self.__critical

    def set_critical_percent(self, number):
        ValueChecker.is_number(number)
        self.__critical = str(number) + '%'
        return self

    def get_critical_percent(self):
        return self.__critical

    def set_warning_inode_percent(self, number):
        ValueChecker.is_number(number)
        self.__inode_warning = number
        return self

    def get_warning_inode_percent(self):
        return self.__inode_warning

    def set_critical_inode_percent(self, number):
        ValueChecker.is_number(number)
        self.__inode_critical = number
        return self

    def get_critical_inode_percent(self):
        return self.__inode_critical

    def set_timeout(self, number):
        ValueChecker.is_number(number)
        self.__timeout = number
        return self

    def get_timeout(self):
        return self.__timeout

    def set_newlines(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__newlines = enabled
        return self

    def get_newlines(self):
        return self.__newlines

    def set_combined_thresholds(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__combined_thresholds = enabled
        return self

    def get_combined_thresholds(self):
        return self.__combined_thresholds

    def set_clear_thresholds(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__clear_thresholds = enabled
        return self

    def get_clear_thresholds(self):
        return self.__clear_thresholds

    def set_freespace_ignore_reserved(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__freespace_ignore_reserved = enabled
        return self

    def get_freespace_ignore_reserved(self):
        return self.__freespace_ignore_reserved

    def set_errors_only(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__errors_only = enabled
        return self

    def get_errors_only(self):
        return self.__errors_only

    def set_local(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__local = enabled
        return self

    def get_local(self):
        return self.__local

    def set_all(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__all = enabled
        return self

    def get_all(self):
        return self.__all

    def set_display_mountpoint(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__display_mountpoint = enabled
        return self

    def get_display_mountpoint(self):
        return self.__display_mountpoint

    def set_stat_remote_fs(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__stat_remote_fs = enabled
        return self

    def get_stat_remote_fs(self):
        return self.__stat_remote_fs

    def set_inode_perfdata(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__inode_perfdata = enabled
        return self

    def get_inode_perfdata(self):
        return self.__inode_perfdata

    def set_skip_fake_fs(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__skip_fake_fs = enabled
        return self

    def get_skip_fake_fs(self):
        return self.__skip_fake_fs

    def set_path(self, path):
        ValueChecker.is_string(path)
        if None is self.__path:
            self.__path = []

        self.__path.append(path)
        return self

    def get_path(self):
        return self.__path

    def set_exclude_device(self, exclude_device):
        ValueChecker.is_string(exclude_device)
        self.__exclude_device = exclude_device
        return self

    def get_exclude_device(self):
        return self.__exclude_device

    def set_partition(self, partition):
        ValueChecker.is_string(partition)
        self.__partition = partition
        return self

    def get_partition(self):
        return self.__partition

    def set_group(self, group):
        ValueChecker.is_string(group)
        self.__group = group
        return self

    def get_group(self):
        return self.__group

    def set_units(self, units):
        ValueChecker.is_string(units)
        self.__units = units
        return self

    def get_units(self):
        return self.__units

    def set_include_type(self, include_type):
        ValueChecker.is_string(include_type)
        if None is self.__include_type:
            self.__include_type = []

        self.__include_type.append(include_type)
        return self

    def get_include_type(self):
        return self.__include_type

    def set_exclude_type(self, exclude_type):
        ValueChecker.is_string(exclude_type)
        if None is self.__exclude_type:
            self.__exclude_type = []

        self.__exclude_type.append(exclude_type)
        return self

    def get_exclude_type(self):
        return self.__exclude_type

    def set_eregi_path(self, eregi_path):
        ValueChecker.is_string(eregi_path)
        if None is self.__eregi_path:
            self.__eregi_path = []
        self.__eregi_path.append(eregi_path)
        return self

    def get_eregi_path(self):
        return self.__eregi_path

    def set_eregi_partition(self, eregi_partition):
        ValueChecker.is_string(eregi_partition)
        self.__eregi_partition = eregi_partition
        return self

    def get_eregi_partition(self):
        return self.__eregi_partition

    def set_ereg_path(self, ereg_path):
        ValueChecker.is_string(ereg_path)
        if None is self.__ereg_path:
            self.__ereg_path = []

        self.__ereg_path.append(ereg_path)
        return self

    def get_ereg_path(self):
        return self.__ereg_path

    def set_ereg_partition(self, ereg_partition):
        ValueChecker.is_string(ereg_partition)
        self.__ereg_partition = ereg_partition
        return self

    def get_ereg_partition(self):
        return self.__ereg_partition

    def set_ignore_eregi_path(self, ignore_eregi_path):
        ValueChecker.is_string(ignore_eregi_path)
        if None is self.__ignore_ereg_path:
            self.__ignore_eregi_path = []
        self.__ignore_eregi_path.append(ignore_eregi_path)
        return self

    def get_ignore_eregi_path(self):
        return self.__ignore_eregi_path

    def set_ignore_eregi_partition(self, ignore_eregi_partition):
        ValueChecker.is_string(ignore_eregi_partition)
        self.__ignore_eregi_partition = ignore_eregi_partition
        return self

    def get_ignore_eregi_partition(self):
        return self.__ignore_eregi_partition

    def set_ignore_ereg_path(self, ignore_ereg_path):
        ValueChecker.is_string(ignore_ereg_path)
        if None is self.__ignore_ereg_path:
            self.__ignore_ereg_path = []

        self.__ignore_ereg_path.append(ignore_ereg_path)
        return self

    def get_ignore_ereg_path(self):
        return self.__ignore_ereg_path

    def set_ignore_ereg_partition(self, ignore_ereg_partition):
        ValueChecker.is_string(ignore_ereg_partition)
        self.__ignore_ereg_partition = ignore_ereg_partition
        return self

    def get_ignore_ereg_partition(self):
        return self.__ignore_ereg_partition

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckDisk(id) \
                .set_check_interval('15m') \
                .add_service_group(ServiceGroup.create('disk').set_display_name('Disk'))
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('disk'):
            DiskCommand.create('disk')

        return check

    def validate(self):
        pass



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Checks.MonitoringPlugins.CheckHttp import CheckHttp
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.ValueChecker import ValueChecker
from icinga2confgen.ValueMapper import ValueMapper


class VHost:

    def __init__(self, id):
        self.__id = id
        self.__hostname = None
        self.__checks = []

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)

        vhost = None if force_create else ConfigBuilder.get_vhost(id)
        if None is vhost:
            vhost = VHost(id)
            ConfigBuilder.add_vhost(id, vhost)

        return vhost

    def get_id(self):
        return self.__id

    def set_hostname(self, hostname):
        ValueChecker.is_string(hostname)
        self.__hostname = hostname
        return self

    def get_hostname(self):
        return self.__hostname

    def add_check(self, check):
        if isinstance(check, CheckHttp):
            check.set_vhost(self.__hostname)
            self.__checks.append(check)

        elif isinstance(check, Check):
            self.__checks.append(check)

        elif isinstance(check, str):
            check = ConfigBuilder.get_check(check)
            if None is check:
                raise Exception('Check does not exist yet!')

            self.__checks.append(check)
        else:
            raise Exception('Can only add Check or id of Check!')

        return self

    def remove_check(self, check):
        if isinstance(check, Check):
            self.__checks.remove(check)

        elif isinstance(check, str):
            check = ConfigBuilder.get_check(check)
            self.__checks.remove(check)

        return self

    def get_check_ids(self):

        return self.__checks

    def get_config(self):
        config = 'template Host "vhost_' + self.__id + '" {\n'
        config += ValueMapper.parse_var('vars.checks', self.__checks, value_prefix='check_')
        config += '}\n'

        return config



#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Downtimes.ScheduledDowntime import ScheduledDowntime


class DefaultScheduledDowntimes:

    @staticmethod
    def weekday_nine_to_five(id='mo_fr_9_17', display_name='Mo-Fr, 9am - 5pm'):
        return ScheduledDowntime.create(id) \
            .set_display_name(display_name) \
            .add_period("monday", "09:00-17:00") \
            .add_period("tuesday", "09:00-17:00") \
            .add_period("wednesday", "09:00-17:00") \
            .add_period("thursday", "09:00-17:00") \
            .add_period("friday", "09:00-17:00")

    @staticmethod
    def continuously(id='24_7', display_name='24/7'):
        return ScheduledDowntime.create(id) \
            .set_display_name(display_name) \
            .add_period("monday", "00:00-24:00") \
            .add_period("tuesday", "00:00-24:00") \
            .add_period("wednesday", "00:00-24:00") \
            .add_period("thursday", "00:00-24:00") \
            .add_period("friday", "00:00-24:00")



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Commands.Command import Command
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.ValueChecker import ValueChecker


class DiskCommand(Command):

    def __init__(self, id):
        Command.__init__(self, id)

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        command = None if force_create else ConfigBuilder.get_command(id)
        if None is command:
            command = DiskCommand(id)
            ConfigBuilder.add_command(id, command)

        return command

    def get_command(self):
        return 'check_disk'

    def get_arguments(self):
        config = """{
    "--warning" = {
      value = "$command_disk_warning$"
      required = true
    }
    "--critical" = {
      value = "$command_disk_critical$"
      required = true
    }
    "--iwarning" = {
      value = "$command_disk_inode_warning$%"
      required = true
    }
    "--icritical" = {
      value = "$command_disk_inode_critical$%"
      required = true
    }
    "--combined-thresholds" = {
      set_if = "$command_disk_combined_thresholds$"
    }
    "--path" = {
      value = "$command_disk_path$"
      set_if = {{ macro("$command_disk_path$") != false }}
      repeat_key = true
    }
    "--partition" = {
      value = "$command_disk_partition$"
      set_if = {{ macro("$command_disk_partition$") != false }}
    }
    "--exclude_device" = {
      value = "$command_disk_exclude_device$"
      set_if = {{ macro("$command_disk_exclude_device$") != false }}
    }
    "--clear" = {
      set_if = "$command_disk_clear_thresholds$"
    }
    "--exact-match" = {
      set_if = "$command_disk_exact_match$"
    }
    "--errors-only" = {
      set_if = "$command_disk_errors_only$"
    }
    "--freespace-ignore-reserved" = {
      set_if = "$command_disk_freespace_ignore_reserved$"
    }
    "--group" = {
      value = "$command_disk_group$"
      set_if = {{ macro("$command_disk_group$") != false }}
    }
    "--local" = {
      set_if = "$command_disk_local$"
    }
    "--skip-fake-fs" = {
      set_if = "$command_disk_skip_fake_fs$"
    }
    "--inode-perfdata" = {
      set_if = "$command_disk_inode_perfdata$"
    }
    "--stat-remote-fs" = {
      set_if = "$command_disk_stat_remote_fs$"
    }
    "--mountpoint" = {
      set_if = "$command_disk_display_mountpoint$"
    }
    "--all" = {
      set_if = "$command_disk_all$"
    }
    "--eregi-path" = {
      value = "$command_disk_eregi_path$"
      set_if = {{ macro("$command_disk_eregi_path$") != false }}
      repeat_key = true
    }
    "--eregi-partition" = {
      value = "$command_disk_eregi_partition$"
      set_if = {{ macro("$command_disk_eregi_partition$") != false }}
    }
    "--ignore-eregi-path" = {
      value = "$command_disk_ignore_eregi_path$"
      set_if = {{ macro("$command_disk_ignore_eregi_path$") != false }}
      repeat_key = true
    }
    "--ignore-eregi-partition" = {
      value = "$command_disk_ignore_eregi_partition$"
      set_if = {{ macro("$command_disk_ignore_eregi_partition$") != false }}
    }
    "--ereg-path" = {
      value = "$command_disk_ereg_path$"
      set_if = {{ macro("$command_disk_ereg_path$") != false }}
      repeat_key = true
    }
    "--ereg-partition" = {
      value = "$command_disk_ereg_partition$"
      set_if = {{ macro("$command_disk_ereg_partition$") != false }}
    }
    "--ignore-ereg-path" = {
      value = "$command_disk_ignore_ereg_path$"
      set_if = {{ macro("$command_disk_ignore_ereg_path$") != false }}
      repeat_key = true
    }
    "--ignore-ereg-partition" = {
      value = "$command_disk_ignore_ereg_partition$"
      set_if = {{ macro("$command_disk_ignore_ereg_partition$") != false }}
    }
    "--timeout" = {
      value = "$command_disk_timeout$"
      set_if = {{ macro("$command_disk_timeout$") != false }}
    }
    "--units" = {
      value = "$command_disk_units$"
      set_if = {{ macro("$command_disk_units$") != false }}
    }
    "--exclude-type" = {
      value = "$command_disk_exclude_type$"
      set_if = {{ macro("$command_disk_exclude_type$") != false }}
      repeat_key = true
  }
    "--include-type" = {
      value = "$command_disk_include_type$"
      set_if = {{ macro("$command_disk_include_type$") != false }}
      repeat_key = true
    }
    "--newlines" = {
      set_if = "$command_disk_newlines$"
    }
  }
"""

        return config



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

import shutil
from pathlib import Path

from tqdm import tqdm

from icinga2confgen.Application.Application import Application
from icinga2confgen.ValueChecker import ValueChecker


class ConfigBuilder:
    __servers = []
    __checks = []
    __templates = []
    __commands = []
    __notification_commands = []
    __vhosts = []
    __hostgroups = []
    __servicegroups = []
    __usergroups = []
    __ssh_templates = []
    __time_periods = []
    __notification_templates = []
    __notifications = []
    __users = []
    __downtimes = []
    __zones = []
    __os = []
    __package_manager = []
    __application = Application.create()
    __pbar = tqdm(desc="Configuring", unit=' Configs')
    __check_for_existence = True

    @staticmethod
    def set_check_for_existence(enabled):
        ConfigBuilder.__check_for_existence = enabled

    @staticmethod
    def replace_prefixes(string):

        for prefix in ValueChecker.get_prefixes():
            if string.startswith(prefix + '_'):
                return string.replace(prefix + '_', '', 1)
        return string

    @staticmethod
    def get_config():
        ConfigBuilder.__pbar.close()

        shutil.rmtree('zones.d', ignore_errors=True)

        global_configs = [
            {'dir': 'checks', 'config': ConfigBuilder.__checks},
            {'dir': 'templates', 'config': ConfigBuilder.__templates},
            {'dir': 'commands', 'config': ConfigBuilder.__commands},
            {'dir': 'vhosts', 'config': ConfigBuilder.__vhosts},
            {'dir': 'groups/servicegroups', 'config': ConfigBuilder.__servicegroups},
            {'dir': 'groups/hostgroups', 'config': ConfigBuilder.__hostgroups},
            {'dir': 'groups/usergroups', 'config': ConfigBuilder.__usergroups},
            {'dir': 'users', 'config': ConfigBuilder.__users},
            {'dir': 'ssh_templates', 'config': ConfigBuilder.__ssh_templates},
            {'dir': 'time_periods', 'config': ConfigBuilder.__time_periods},
            {'dir': 'notifications/templates', 'config': ConfigBuilder.__notification_templates},
            {'dir': 'notifications/notifications', 'config': ConfigBuilder.__notifications},
            {'dir': 'notifications/commands', 'config': ConfigBuilder.__notification_commands},
            {'dir': 'downtimes', 'config': ConfigBuilder.__downtimes},
            {'dir': 'os', 'config': ConfigBuilder.__os},
            {'dir': 'package_manager', 'config': ConfigBuilder.__package_manager},
        ]

        total = len(ConfigBuilder.__servers)
        for config in global_configs:
            total += len(config['config'])

        pbar = tqdm(total=total, desc="Writing config", unit=' Configs')

        for config in global_configs:
            dirpath = "zones.d/global-templates/" + config['dir']
            for conf in config['config']:
                Path(dirpath).mkdir(parents=True, exist_ok=True)
                with open(dirpath + '/' + ConfigBuilder.replace_prefixes(conf['id']) + '.conf', "w") as file:
                    file.write(conf['instance'].get_config())
                pbar.update(1)

        for conf in ConfigBuilder.__servers:
            server = conf['instance']
            zone = server.get_zone()
            dirpath = 'zones.d/' + ConfigBuilder.replace_prefixes(zone.get_id()) + '/'

            Path(dirpath).mkdir(parents=True, exist_ok=True)
            with open(dirpath + '/' + ConfigBuilder.replace_prefixes(conf['id']) + '.conf', "w") as file:
                file.write(server.get_config())
            pbar.update(1)

        with open('zones.d/application.conf', "w") as file:
            file.write(ConfigBuilder.__application.get_config())
            pbar.update(1)

        pbar.close()

    @staticmethod
    def get_hosts_with_hostgroup(group):
        servers_with_group = []
        for server in ConfigBuilder.__servers:
            if group in server.get_hostgroups():
                servers_with_group.append(server)

        return servers_with_group

    @staticmethod
    def get_checks_from_server(server):
        all_checks = server.get_checks()
        for template in server.get_templates():
            all_checks += ConfigBuilder.get_checks_from_server(template)

        return all_checks

    @staticmethod
    def get_instance(type):

        config = {
            'server': ConfigBuilder.__servers,
            'checks': ConfigBuilder.__checks,
            'templates': ConfigBuilder.__templates,
            'commands': ConfigBuilder.__commands,
            'vhosts': ConfigBuilder.__vhosts,
            'servicegroups': ConfigBuilder.__servicegroups,
            'hostgroups': ConfigBuilder.__hostgroups,
            'usergroups': ConfigBuilder.__usergroups,
            'users': ConfigBuilder.__users,
            'sshtemplates': ConfigBuilder.__ssh_templates,
            'time_periods': ConfigBuilder.__time_periods,
            'notification_templates': ConfigBuilder.__notification_templates,
            'notification_commands': ConfigBuilder.__notification_commands,
            'notifications': ConfigBuilder.__notifications,
            'downtimes': ConfigBuilder.__downtimes,
            'os': ConfigBuilder.__os,
            'package_manager': ConfigBuilder.__package_manager
        }

        instances_config = config[type]
        instances = []

        for config in instances_config:
            instances.append(config['instance'])

        return instances

    @staticmethod
    def get_server(id):
        for server in ConfigBuilder.__servers:
            if server['id'] == id:
                return server['instance']

        return None

    @staticmethod
    def add_server(id, server):
        if ConfigBuilder.__check_for_existence and None is not ConfigBuilder.get_check(id):
            raise Exception('Server with id ' + id + ' already exists!')

        ConfigBuilder.__servers.append({'id': id, 'instance': server})
        ConfigBuilder.__pbar.update(1)

    @staticmethod
    def get_check(id):

        for check in ConfigBuilder.__checks:
            if check['id'] == id:
                return check['instance']

        return None

    @staticmethod
    def add_check(id, check):
        if ConfigBuilder.__check_for_existence and None is not ConfigBuilder.get_check(id):
            raise Exception('Check with id ' + id + ' already exists!')

        ConfigBuilder.__checks.append({'id': id, 'instance': check})
        ConfigBuilder.__pbar.update(1)

    @staticmethod
    def get_template(id):
        for template in ConfigBuilder.__templates:
            if template['id'] == id:
                return template['instance']

        return None

    @staticmethod
    def add_template(id, template):
        if ConfigBuilder.__check_for_existence and None is not ConfigBuilder.get_template(id):
            raise Exception('Template with id ' + id + ' already exists!')

        ConfigBuilder.__templates.append({'id': id, 'instance': template})
        ConfigBuilder.__pbar.update(1)

    @staticmethod
    def get_command(id):
        for command in ConfigBuilder.__commands:
            if command['id'] == id:
                return command['instance']

        return None

    @staticmethod
    def add_command(id, command):
        if ConfigBuilder.__check_for_existence and None is not ConfigBuilder.get_command(id):
            raise Exception('Command with id ' + id + ' already exists!')

        ConfigBuilder.__commands.append({'id': id, 'instance': command})
        ConfigBuilder.__pbar.update(1)

    @staticmethod
    def get_notification_command(id):
        for notification_command in ConfigBuilder.__notification_commands:
            if notification_command['id'] == id:
                return notification_command['instance']

        return None

    @staticmethod
    def add_notification_command(id, notification_command):
        if ConfigBuilder.__check_for_existence and None is not ConfigBuilder.get_notification_command(id):
            raise Exception('NotificationCommand with id ' + id + ' already exists!')

        ConfigBuilder.__notification_commands.append({'id': id, 'instance': notification_command})
        ConfigBuilder.__pbar.update(1)

    @staticmethod
    def get_vhost(id):
        for vhost in ConfigBuilder.__vhosts:
            if vhost['id'] == id:
                return vhost['instance']

        return None

    @staticmethod
    def add_vhost(id, vhost):
        if ConfigBuilder.__check_for_existence and None is not ConfigBuilder.get_vhost(id):
            raise Exception('vHost with id ' + id + ' already exists!')

        ConfigBuilder.__vhosts.append({'id': id, 'instance': vhost})
        ConfigBuilder.__pbar.update(1)

    @staticmethod
    def get_hostgroup(id):
        for group in ConfigBuilder.__hostgroups:
            if group['id'] == id:
                return group['instance']

        return None

    @staticmethod
    def add_hostgroup(id, group):
        if ConfigBuilder.__check_for_existence and None is not ConfigBuilder.get_hostgroup(id):
            raise Exception('Hostgroup with id ' + id + ' already exists!')

        ConfigBuilder.__hostgroups.append({'id': id, 'instance': group})
        ConfigBuilder.__pbar.update(1)

    @staticmethod
    def get_usergroup(id):
        for group in ConfigBuilder.__usergroups:
            if group['id'] == id:
                return group['instance']

        return None

    @staticmethod
    def add_usergroup(id, group):
        if ConfigBuilder.__check_for_existence and None is not ConfigBuilder.get_usergroup(id):
            raise Exception('Usergroup with id ' + id + ' already exists!')

        ConfigBuilder.__usergroups.append({'id': id, 'instance': group})
        ConfigBuilder.__pbar.update(1)

    @staticmethod
    def get_servicegroup(id):
        for group in ConfigBuilder.__servicegroups:
            if group['id'] == id:
                return group['instance']

        return None

    @staticmethod
    def add_servicegroup(id, group):
        if ConfigBuilder.__check_for_existence and None is not ConfigBuilder.get_servicegroup(id):
            raise Exception('Servicegroup with id ' + id + ' already exists!')

        ConfigBuilder.__servicegroups.append({'id': id, 'instance': group})
        ConfigBuilder.__pbar.update(1)

    @staticmethod
    def get_ssh_template(id):
        for template in ConfigBuilder.__ssh_templates:
            if template['id'] == id:
                return template['instance']

        return None

    @staticmethod
    def add_ssh_template(id, group):
        if ConfigBuilder.__check_for_existence and None is not ConfigBuilder.get_ssh_template(id):
            raise Exception('SSH Template with id ' + id + ' already exists!')

        ConfigBuilder.__ssh_templates.append({'id': id, 'instance': group})
        ConfigBuilder.__pbar.update(1)

    @staticmethod
    def get_time_period(id):
        for period in ConfigBuilder.__time_periods:
            if period['id'] == id:
                return period['instance']

        return None

    @staticmethod
    def add_time_period(id, period):
        if ConfigBuilder.__check_for_existence and None is not ConfigBuilder.get_time_period(id):
            raise Exception('Time Period with id ' + id + ' already exists!')

        ConfigBuilder.__time_periods.append({'id': id, 'instance': period})
        ConfigBuilder.__pbar.update(1)

    @staticmethod
    def get_notification_template(id):
        for template in ConfigBuilder.__notification_templates:
            if template['id'] == id:
                return template['instance']

        return None

    @staticmethod
    def add_notification_template(id, period):
        if ConfigBuilder.__check_for_existence and None is not ConfigBuilder.get_notification_template(id):
            raise Exception('Notification Template with id ' + id + ' already exists!')

        ConfigBuilder.__notification_templates.append({'id': id, 'instance': period})
        ConfigBuilder.__pbar.update(1)

    @staticmethod
    def get_notification(id):
        id = 'notification_' + id
        for notification in ConfigBuilder.__notifications:
            if ['id'] == id:
                return notification['instance']

        return None

    @staticmethod
    def add_notification(id, period):
        if ConfigBuilder.__check_for_existence and None is not ConfigBuilder.get_notification(id):
            raise Exception('Notification with id ' + id + ' already exists!')

        ConfigBuilder.__notifications.append({'id': id, 'instance': period})
        ConfigBuilder.__pbar.update(1)

    @staticmethod
    def get_user(id):
        for user in ConfigBuilder.__users:
            if user['id'] == id:
                return user['instance']

        return None

    @staticmethod
    def add_user(id, user):
        if ConfigBuilder.__check_for_existence and None is not ConfigBuilder.get_user(id):
            raise Exception('user with id ' + id + ' already exists!')

        ConfigBuilder.__users.append({'id': id, 'instance': user})
        ConfigBuilder.__pbar.update(1)

    @staticmethod
    def get_downtime(id):
        for period in ConfigBuilder.__downtimes:
            if period['id'] == id:
                return period['instance']

        return None

    @staticmethod
    def add_downtime(id, period):
        if ConfigBuilder.__check_for_existence and None is not ConfigBuilder.get_downtime(id):
            raise Exception('Downtime with id ' + id + ' already exists!')

        ConfigBuilder.__downtimes.append({'id': id, 'instance': period})
        ConfigBuilder.__pbar.update(1)

    @staticmethod
    def get_application():
        return ConfigBuilder.__application

    @staticmethod
    def set_application(application):
        if not isinstance(application, Application):
            raise Exception('Can only set Application')

        ConfigBuilder.__application = application
        ConfigBuilder.__pbar.update(1)

    @staticmethod
    def get_zone(id):
        for period in ConfigBuilder.__zones:
            if period['id'] == id:
                return period['instance']

        return None

    @staticmethod
    def add_zone(id, period):
        if ConfigBuilder.__check_for_existence and None is not ConfigBuilder.get_zone(id):
            raise Exception('Zone with id ' + id + ' already exists!')

        ConfigBuilder.__zones.append({'id': id, 'instance': period})
        ConfigBuilder.__pbar.update(1)

    @staticmethod
    def get_os(id):
        for period in ConfigBuilder.__os:
            if period['id'] == id:
                return period['instance']

        return None

    @staticmethod
    def add_os(id, os):
        if ConfigBuilder.__check_for_existence and None is not ConfigBuilder.get_os(id):
            raise Exception('os with id ' + id + ' already exists!')

        ConfigBuilder.__os.append({'id': id, 'instance': os})
        ConfigBuilder.__pbar.update(1)

    @staticmethod
    def get_package_manager(id):
        for period in ConfigBuilder.__package_manager:
            if period['id'] == id:
                return period['instance']

        return None

    @staticmethod
    def add_package_manager(id, package_manager):
        if ConfigBuilder.__check_for_existence and None is not ConfigBuilder.get_package_manager(id):
            raise Exception('package_manager with id ' + id + ' already exists!')

        ConfigBuilder.__package_manager.append({'id': id, 'instance': package_manager})
        ConfigBuilder.__pbar.update(1)



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.MonitoringPlugins.IfStatusCommand import IfStatusCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckIfStatus(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckIfStatus', 'ifstatus')
        self.__host = None
        self.__port = 161
        self.__community = None
        self.__snmp_version = None
        self.__if_mib = False
        self.__snmp_exclude = None
        self.__unused_ports_by_name = None
        self.__unused_ports = None
        self.__seclevel = None
        self.__secname = None
        self.__context = None
        self.__authpass = None
        self.__authproto = None
        self.__privpass = None
        self.__privproto = None
        self.__max_msg_size = None
        self.__timeout = 10
        self.add_service_group(ServiceGroup.create('network'))
        self.add_service_group(ServiceGroup.create('ifstatus'))

    def set_host(self, host):
        ValueChecker.is_string(host)
        self.__host = host
        return self

    def get_host(self):
        return self.__host

    def set_port(self, port):
        ValueChecker.is_number(port)
        self.__port = port
        return self

    def get_port(self):
        return self.__port

    def set_community(self, community):
        ValueChecker.is_string(community)
        self.__community = community
        return self

    def get_community(self):
        return self.__community

    def set_snmp_version(self, snmp_version):
        ValueChecker.is_string(snmp_version)
        self.__snmp_version = snmp_version
        return self

    def get_snmp_version(self):
        return self.__snmp_version

    def set_if_mib(self, if_mib):
        ValueChecker.is_bool(if_mib)
        self.__if_mib = if_mib
        return self

    def get_if_mib(self):
        return self.__if_mib

    def set_snmp_exclude(self, snmp_exclude):
        ValueChecker.is_string(snmp_exclude)
        self.__snmp_exclude = snmp_exclude
        return self

    def get_snmp_exclude(self):
        return self.__snmp_exclude

    def set_unused_ports_by_name(self, unused_ports_by_name):
        ValueChecker.is_string(unused_ports_by_name)
        self.__unused_ports_by_name = unused_ports_by_name
        return self

    def get_unused_ports_by_name(self):
        return self.__unused_ports_by_name

    def set_unused_ports(self, unused_ports):
        ValueChecker.is_string(unused_ports)
        self.__unused_ports = unused_ports
        return self

    def get_unused_ports(self):
        return self.__unused_ports

    def set_seclevel(self, seclevel):
        ValueChecker.is_string(seclevel)
        self.__seclevel = seclevel
        return self

    def get_seclevel(self):
        return self.__seclevel

    def set_secname(self, secname):
        ValueChecker.is_string(secname)
        self.__secname = secname
        return self

    def get_secname(self):
        return self.__secname

    def set_context(self, context):
        ValueChecker.is_string(context)
        self.__context = context
        return self

    def get_context(self):
        return self.__context

    def set_authpass(self, authpass):
        ValueChecker.is_string(authpass)
        self.__authpass = authpass
        return self

    def get_authpass(self):
        return self.__authpass

    def set_authproto(self, authproto):
        ValueChecker.is_string(authproto)
        self.__authproto = authproto
        return self

    def get_authproto(self):
        return self.__authproto

    def set_privpass(self, privpass):
        ValueChecker.is_string(privpass)
        self.__privpass = privpass
        return self

    def get_privpass(self):
        return self.__privpass

    def set_privproto(self, privproto):
        ValueChecker.is_string(privproto)
        self.__privproto = privproto
        return self

    def get_privproto(self):
        return self.__privproto

    def set_max_msg_size(self, max_msg_size):
        ValueChecker.is_number(max_msg_size)
        self.__max_msg_size = max_msg_size
        return self

    def get_max_msg_size(self):
        return self.__max_msg_size

    def set_timeout(self, timeout):
        ValueChecker.is_number(timeout)
        self.__timeout = timeout
        return self

    def get_timeout(self):
        return self.__timeout

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckIfStatus(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('ifstatus'):
            IfStatusCommand.create('ifstatus')

        return check

    def validate(self):
        if None is self.__community:
            raise Exception('You have to specify a community for ' + self.get_id())
        if None is self.__host:
            raise Exception('You have to specify a host for ' + self.get_id())



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.MonitoringPlugins.ICMPCommand import ICMPCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckICMP(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckICMP', 'icmp')
        self.__host = None
        self.__use_ipv4 = False
        self.__use_ipv6 = False
        self.__source = None
        self.__packets = 2
        self.__packet_interval = None
        self.__minimum_hosts = None
        self.__ttl = 5
        self.__timeout = 10
        self.__bytes = 76
        self.__warning = None
        self.__critical = None
        self.add_service_group(ServiceGroup.create('icmp'))
        self.add_service_group(ServiceGroup.create('network'))

    def set_host(self, host):
        ValueChecker.is_string(host)
        self.__host = host
        return self

    def get_host(self):
        return self.__host

    def set_use_ipv4(self, use_ipv4):
        ValueChecker.is_bool(use_ipv4)
        self.__use_ipv4 = use_ipv4
        return self

    def get_use_ipv4(self):
        return self.__use_ipv4

    def set_use_ipv6(self, use_ipv6):
        ValueChecker.is_bool(use_ipv6)
        self.__use_ipv6 = use_ipv6
        return self

    def get_use_ipv6(self):
        return self.__use_ipv6

    def set_warning(self, warning):
        ValueChecker.is_string(warning)
        self.__warning = warning
        return self

    def get_warning(self):
        return self.__warning

    def set_critical(self, critical):
        ValueChecker.is_string(critical)
        self.__critical = critical
        return self

    def get_critical(self):
        return self.__critical

    def set_source(self, source):
        ValueChecker.is_string(source)
        self.__source = source
        return self

    def get_source(self):
        return self.__source

    def set_packets(self, packets):
        ValueChecker.is_number(packets)
        self.__packets = packets
        return self

    def get_packets(self):
        return self.__packets

    def set_packet_interval(self, packet_interval):
        ValueChecker.is_string(packet_interval)
        self.__packet_interval = packet_interval
        return self

    def get_packet_interval(self):
        return self.__packet_interval

    def set_minimum_hosts(self, minimum_hosts):
        ValueChecker.is_string(minimum_hosts)
        self.__minimum_hosts = minimum_hosts
        return self

    def get_minimum_hosts(self):
        return self.__minimum_hosts

    def set_ttl(self, ttl):
        ValueChecker.is_number(ttl)
        self.__ttl = ttl
        return self

    def get_ttl(self):
        return self.__ttl

    def set_bytes(self, bytes):
        ValueChecker.is_number(bytes)
        self.__bytes = bytes
        return self

    def get_bytes(self):
        return self.__bytes

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckICMP(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('icmp'):
            ICMPCommand.create('icmp')

        return check

    def validate(self):
        if None is self.__host:
            raise Exception('You have to specify a host for ' + self.get_id())



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.
from icinga2confgen.OS.OS import OS
from icinga2confgen.PackageManager.PackageManager import apt


def os_ubuntu_4_10(): return OS.create('ubuntu_4_10').set_distro('ubuntu').set_version('4.10').set_os(
    'Ubuntu 4.10 STS (Warty Warthog)').append_package_manager(apt())


def os_ubuntu_5_04(): return OS.create('ubuntu_5_04').set_distro('ubuntu').set_version('5.04').set_os(
    'Ubuntu 5.04 STS (Hoary Hedgehog)').append_package_manager(apt())


def os_ubuntu_5_10(): return OS.create('ubuntu_5_10').set_distro('ubuntu').set_version('5.10').set_os(
    'Ubuntu 5.10 STS (Breezy Badger)').append_package_manager(apt())


def os_ubuntu_6_06(): return OS.create('ubuntu_6_06').set_distro('ubuntu').set_version('6.06').set_os(
    'Ubuntu 6.06 LTS (Dapper Drake)').append_package_manager(apt())


def os_ubuntu_6_10(): return OS.create('ubuntu_6_10').set_distro('ubuntu').set_version('6.10').set_os(
    'Ubuntu 6.10 STS (Edgy Eft)').append_package_manager(apt())


def os_ubuntu_7_04(): return OS.create('ubuntu_7_04').set_distro('ubuntu').set_version('7.04').set_os(
    'Ubuntu 7.04 STS (Feisty Fawn)').append_package_manager(apt())


def os_ubuntu_7_10(): return OS.create('ubuntu_7_10').set_distro('ubuntu').set_version('7.10').set_os(
    'Ubuntu 7.10 STS (Gutsy Gibbon)').append_package_manager(apt())


def os_ubuntu_8_04(): return OS.create('ubuntu_8_04').set_distro('ubuntu').set_version('8.04').set_os(
    'Ubuntu 8.04 LTS (Hardy Heron)').append_package_manager(apt())


def os_ubuntu_8_10(): return OS.create('ubuntu_8_10').set_distro('ubuntu').set_version('8.10').set_os(
    'Ubuntu 8.10 STS (Intrepid Ibex)').append_package_manager(apt())


def os_ubuntu_9_04(): return OS.create('ubuntu_9_04').set_distro('ubuntu').set_version('9.04').set_os(
    'Ubuntu 9.04 STS (Jaunty Jackalope)').append_package_manager(apt())


def os_ubuntu_9_10(): return OS.create('ubuntu_9_10').set_distro('ubuntu').set_version('9.10').set_os(
    'Ubuntu 9.10 STS (Karmic Koala)').append_package_manager(apt())


def os_ubuntu_10_04(): return OS.create('ubuntu_10_04').set_distro('ubuntu').set_version('10.04').set_os(
    'Ubuntu 10.04 LTS (Lucid Lynx)').append_package_manager(apt())


def os_ubuntu_10_10(): return OS.create('ubuntu_10_10').set_distro('ubuntu').set_version('10.10').set_os(
    'Ubuntu 10.10 STS (Maverick Meerkat)').append_package_manager(apt())


def os_ubuntu_11_04(): return OS.create('ubuntu_11_04').set_distro('ubuntu').set_version('11.04').set_os(
    'Ubuntu 11.04 STS (Natty Narwhal)').append_package_manager(apt())


def os_ubuntu_11_10(): return OS.create('ubuntu_11_10').set_distro('ubuntu').set_version('11.10').set_os(
    'Ubuntu 11.10 STS (Oneiric Ocelot)').append_package_manager(apt())


def os_ubuntu_12_04(): return OS.create('ubuntu_12_04').set_distro('ubuntu').set_version('12.04').set_os(
    'Ubuntu 12.04 LTS (Precise Pangolin)').append_package_manager(apt())


def os_ubuntu_12_10(): return OS.create('ubuntu_12_10').set_distro('ubuntu').set_version('12.10').set_os(
    'Ubuntu 12.10 STS (Quantal Quetzal)').append_package_manager(apt())


def os_ubuntu_13_04(): return OS.create('ubuntu_13_04').set_distro('ubuntu').set_version('13.04').set_os(
    'Ubuntu 13.04 STS (Raring Ringtail)').append_package_manager(apt())


def os_ubuntu_13_10(): return OS.create('ubuntu_13_10').set_distro('ubuntu').set_version('13.10').set_os(
    'Ubuntu 13.10 STS (Saucy Salamander)').append_package_manager(apt())


def os_ubuntu_14_04(): return OS.create('ubuntu_14_04').set_distro('ubuntu').set_version('14.04').set_os(
    'Ubuntu 14.04 LTS (Trusty Tahr)').append_package_manager(apt())


def os_ubuntu_14_10(): return OS.create('ubuntu_14_10').set_distro('ubuntu').set_version('14.10').set_os(
    'Ubuntu 14.10 STS (Utopic Unicorn)').append_package_manager(apt())


def os_ubuntu_15_04(): return OS.create('ubuntu_15_04').set_distro('ubuntu').set_version('15.04').set_os(
    'Ubuntu 15.04 STS (Vivid Vervet)').append_package_manager(apt())


def os_ubuntu_15_10(): return OS.create('ubuntu_15_10').set_distro('ubuntu').set_version('15.10').set_os(
    'Ubuntu 15.10 STS (Wily Werewolf)').append_package_manager(apt())


def os_ubuntu_16_04(): return OS.create('ubuntu_16_04').set_distro('ubuntu').set_version('16.04').set_os(
    'Ubuntu 16.04 LTS (Xenial Xerus)').append_package_manager(apt())


def os_ubuntu_16_10(): return OS.create('ubuntu_16_10').set_distro('ubuntu').set_version('16.10').set_os(
    'Ubuntu 16.10 STS (Yakkety Yak)').append_package_manager(apt())


def os_ubuntu_17_04(): return OS.create('ubuntu_17_04').set_distro('ubuntu').set_version('17.04').set_os(
    'Ubuntu 17.04 STS (Zesty Zapus)').append_package_manager(apt())


def os_ubuntu_17_10(): return OS.create('ubuntu_17_10').set_distro('ubuntu').set_version('17.10').set_os(
    'Ubuntu 17.10 STS (Artful Aardvark)').append_package_manager(apt())


def os_ubuntu_18_04(): return OS.create('ubuntu_18_04').set_distro('ubuntu').set_version('18.04').set_os(
    'Ubuntu 18.04 LTS (Bionic Beaver)').append_package_manager(apt())


def os_ubuntu_18_10(): return OS.create('ubuntu_18_10').set_distro('ubuntu').set_version('18.10').set_os(
    'Ubuntu 18.10 STS (Cosmic Cuttlefish)').append_package_manager(apt())


def os_ubuntu_19_04(): return OS.create('ubuntu_19_04').set_distro('ubuntu').set_version('19.04').set_os(
    'Ubuntu 19.04 STS (Disco Dingo)').append_package_manager(apt())


def os_ubuntu_19_10(): return OS.create('ubuntu_19_10').set_distro('ubuntu').set_version('19.10').set_os(
    'Ubuntu 19.10 STS (Eoan Ermine)').append_package_manager(apt())


def os_ubuntu_20_04(): return OS.create('ubuntu_20_04').set_distro('ubuntu').set_version('20.04').set_os(
    'Ubuntu 20.04 LTS (Focal Fossa)').append_package_manager(apt())


def os_ubuntu_20_10(): return OS.create('ubuntu_20_10').set_distro('ubuntu').set_version('20.10').set_os(
    'Ubuntu 20.10 STS (Groovy Gorilla)').append_package_manager(apt())



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Downtimes.ScheduledDowntime import ScheduledDowntime
from icinga2confgen.Groups.HostGroup import HostGroup
from icinga2confgen.Notification.Notification import Notification
from icinga2confgen.OS.OS import OS
from icinga2confgen.PackageManager.PackageManager import PackageManager
from icinga2confgen.Servers.SSHTemplate import SSHTemplate
from icinga2confgen.Servers.VHost import VHost
from icinga2confgen.Servers.Zone import Zone
from icinga2confgen.ValueChecker import ValueChecker
from icinga2confgen.ValueMapper import ValueMapper


class ServerTemplate:

    def __init__(self, id):
        self.__id = id
        self.__ipv4 = None
        self.__ipv6 = None
        self.__display_name = None
        self.__ssh_template = None
        self.__os = None
        self.__checks = []
        self.__vhosts = []
        self.__templates = []
        self.__custom_vars = []
        self.__groups = []
        self.__notifications = []
        self.__downtimes = []
        self.__package_manager = []
        self.__plugin_dir = '/usr/lib/nagios/plugins/'
        self.__max_check_attempts = 3
        self.__check_interval = '1m'
        self.__retry_interval = '15s'
        self.__enable_perfdata = True
        self.__execution_zone = Zone.create('master')

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)

        template = None if force_create else ConfigBuilder.get_template(id)
        if None is template:
            template = ServerTemplate(id)
            ConfigBuilder.add_template(id, template)

        return template

    def get_id(self):
        return self.__id

    def set_plugindir(self, dir):
        ValueChecker.is_string(dir)
        self.__plugin_dir = dir
        return self

    def get_plugindir(self):
        return self.__plugin_dir

    def set_execution_zone(self, zone):
        if isinstance(zone, Zone):
            self.__execution_zone = zone

        elif isinstance(zone, str):
            zone = ConfigBuilder.get_zone(zone)
            if None is zone:
                raise Exception('Zone does not exist yet!')
            self.__execution_zone = zone
        else:
            raise Exception('Can only add Zone or id of Zone!')

        return self

    def get_execution_zone(self):
        return self.__plugin_dir

    def set_max_check_attempts(self, max_check_attempts):
        ValueChecker.is_number(max_check_attempts)
        self.__max_check_attempts = max_check_attempts
        return self

    def get_max_check_attempts(self):
        return self.__max_check_attempts

    def set_check_interval(self, check_interval):
        ValueChecker.is_string(check_interval)
        self.__check_interval = check_interval
        return self

    def get_check_interval(self):
        return self.__check_interval

    def set_retry_interval(self, retry_interval):
        ValueChecker.is_string(retry_interval)
        self.__retry_interval = retry_interval
        return self

    def get_retry_interval(self):
        return self.__retry_interval

    def set_enable_perfdata(self, enable_perfdata):
        ValueChecker.is_bool(enable_perfdata)
        self.__enable_perfdata = enable_perfdata
        return self

    def get_enable_perfdata(self):
        return self.__enable_perfdata

    def set_ipv4(self, ip):
        ValueChecker.is_string(ip)
        self.__ipv4 = ip
        return self

    def get_ipv4(self):
        return self.__ipv4

    def set_ipv6(self, ip):
        ValueChecker.is_string(ip)
        self.__ipv6 = ip
        return self

    def get_ipv6(self):
        return self.__ipv6

    def get_display_name(self):
        return self.__display_name

    def set_display_name(self, name):
        ValueChecker.is_string(name)
        self.__display_name = name
        return self

    def set_ssh_template(self, ssh_template):

        if isinstance(ssh_template, SSHTemplate):
            self.__ssh_template = ssh_template

        elif isinstance(ssh_template, str):
            ssh_template = ConfigBuilder.get_ssh_template(ssh_template)
            if None is ssh_template:
                raise Exception('SSHTemplate does not exist yet!')
            self.__ssh_template = ssh_template
        else:
            raise Exception('Can only add SSHTemplate or id of SSHTemplate!')

        return self

    def set_os(self, os):

        if isinstance(os, OS):
            self.__os = os

        elif isinstance(os, str):
            os = ConfigBuilder.get_os(os)
            if None is os:
                raise Exception('OS does not exist yet!')
            self.__os = os
        else:
            raise Exception('Can only add OS or id of OS!')

        return self

    def add_downtime(self, downtime):
        if isinstance(downtime, ScheduledDowntime):
            self.__downtimes.append(downtime)
        elif isinstance(downtime, str):
            downtime = ConfigBuilder.get_downtime(downtime)
            if None is downtime:
                raise Exception('Downtime does not exist yet!')
            self.__downtimes.append(downtime)
        else:
            raise Exception('Can only add Downtime or id of Downtime!')

        return self

    def remove_downtime(self, downtime):
        if isinstance(downtime, ScheduledDowntime):
            self.__downtimes.remove(downtime.get_id())
        elif isinstance(downtime, str):
            self.__downtimes.remove('downtime_' + downtime)

        return self

    def get_ssh_template(self):
        return self.__ssh_template

    def add_notification(self, notification):
        if isinstance(notification, Notification):
            self.__notifications.append(notification)
        elif isinstance(notification, str):
            notification = ConfigBuilder.get_notification(notification)
            if None is notification:
                raise Exception('Notification does not exist yet!')

            self.__notifications.append(notification)
        else:
            raise Exception('Can only add Notification or id of Notification!')

        return self

    def remove_notification(self, notification):

        if isinstance(notification, HostNotification):
            self.__notifications.remove(notification)

        elif isinstance(notification, str):
            notification = ConfigBuilder.get_notification(notification)
            self.__notifications.remove(notification)

        return self

    def add_check(self, check):
        if isinstance(check, Check):
            if check not in self.__checks:
                self.__checks.append(check)

        elif isinstance(check, str):
            check = ConfigBuilder.get_check(check)
            if None is check:
                raise Exception('Check does not exist yet!')
            self.add_check(check)
        else:
            raise Exception('Can only add Check or id of Check!')

        return self

    def add_checks(self):

        return self.__checks

    def remove_check(self, check):
        if isinstance(check, Check):
            self.__checks.remove(check)

        elif isinstance(check, str):
            check = ConfigBuilder.get_check(check)
            self.__checks.remove(check)

        return self

    def get_check_ids(self):

        return self.__checks

    def add_vhost(self, vhost):
        if isinstance(vhost, VHost):
            if vhost not in self.__vhosts:
                self.__vhosts.append(vhost)

        elif isinstance(vhost, str):
            vhost = ConfigBuilder.get_vhost(vhost)
            if None is vhost:
                raise Exception('VHost does not exist yet')

            self.add_vhost(vhost)

        else:
            raise Exception('Can only add VHost or id of VHost!')

        return self

    def remove_vhost(self, vhost):
        if isinstance(vhost, VHost):
            self.__vhosts.remove(vhost)

        elif isinstance(vhost, str):
            vhost = ConfigBuilder.get_vhost(vhost)
            self.__vhosts.remove(vhost)

        return self

    def get_vhost_ids(self):

        return self.__vhosts

    def add_template(self, template):
        if isinstance(template, ServerTemplate):
            if template not in self.__templates:
                self.__templates.append(template)

        elif isinstance(template, str):
            template = ConfigBuilder.get_template(template)
            if None is template:
                raise Exception('ServerTemplate does not exist yet!')
            self.add_template(template)
        else:
            raise Exception('Can only add ServerTemplate or id of ServerTemplate!')

        return self

    def remove_template(self, template):
        if isinstance(template, ServerTemplate):
            self.__templates.remove(template.get_id())
        elif isinstance(template, str):
            template = ConfigBuilder.get_template(template)
            self.__templates.remove(template)

        return self

    def get_templates(self):

        return self.__templates

    def add_hostgroup(self, group):
        if isinstance(group, HostGroup):
            if group not in self.__groups:
                self.__groups.append(group)
        elif isinstance(group, str):
            group = ConfigBuilder.get_hostgroup(group)
            if None is group:
                raise Exception('HostGroup does not exist yet!')
            self.add_hostgroup(group)
        else:
            raise Exception('Can only add Hostgroup or id of Hostgroup!')

        return self

    def get_hostgroups(self):
        return self.__groups

    def remove_hostgroup(self, group):
        if isinstance(group, HostGroup):
            self.__groups.remove(group)
        elif isinstance(group, str):
            group = ConfigBuilder.get_hostgroup(group)
            self.__groups.remove(group)
        else:
            raise Exception('Can only add Hostgroup or id of Hostgroup!')

        return self

    def add_custom_var(self, key, value):
        self.__custom_vars.append({'key': key, 'value': value})
        return self

    def remove_custom_var(self, key):
        vars = self.__custom_vars
        self.__custom_vars = []
        for var in vars:
            if var['key'] != key:
                self.__custom_vars.append(var)
        return self

    def get_custom_var(self, key):
        for var in self.__custom_vars:
            if var['key'] == key:
                return var['value']

        last_value = None

        for template in self.__templates:
            if None is not template:
                new_value = template.get_custom_var(key)
                if None is not new_value:
                    last_value = new_value

        return last_value

    def append_package_manager(self, package_manager):

        if isinstance(package_manager, PackageManager):
            if package_manager not in self.__package_manager:
                self.__package_manager.append(package_manager)

        elif isinstance(package_manager, str):
            package_manager = ConfigBuilder.get_package_manager(package_manager)
            if None is package_manager:
                raise Exception('PackageManager does not exist yet!')
            self.append_package_manager(package_manager)
        else:
            raise Exception('Can only add PackageManager or id of PackageManager!')

        return self

    def remove_package_manager(self, package_manager):

        if isinstance(package_manager, PackageManager):
            self.__package_manager.remove(package_manager)

        elif isinstance(package_manager, str):
            package_manager = ConfigBuilder.get_package_manager(package_manager)
            self.__package_manager.remove(package_manager)

        return self

    def get_config(self):
        config = 'template Host "servertemplate_' + self.__id + '" {\n'

        for template in self.__templates:
            config += '  import "servertemplate_' + template.get_id() + '"\n'

        for vhost in self.__vhosts:
            config += '  import "vhost_' + vhost.get_id() + '"\n'

        if None is not self.__ssh_template:
            config += '  import "sshtemplate_' + self.__ssh_template.get_id() + '"\n'

        if None is not self.__os:
            config += '  import "os_' + self.__os.get_id() + '"\n'

        for manager in self.__package_manager:
            config += '  import "packagemanager_' + manager.get_id() + '"\n'

        config += '  check_interval = ' + self.__check_interval + '\n'
        config += '  retry_interval = ' + self.__retry_interval + '\n'
        config += ValueMapper.parse_var('vars.notification', self.__notifications, value_prefix='notification_')
        config += ValueMapper.parse_var('vars.downtime', self.__downtimes, value_prefix='downtime_')
        config += ValueMapper.parse_var('address', self.__ipv4)
        config += ValueMapper.parse_var('address6', self.__ipv6)
        config += ValueMapper.parse_var('display_name', self.__display_name)
        config += ValueMapper.parse_var('max_check_attempts', self.__max_check_attempts)
        config += ValueMapper.parse_var('enable_perfdata', self.__enable_perfdata)
        config += ValueMapper.parse_var('vars.plugin_dir', self.__plugin_dir)
        config += ValueMapper.parse_var('vars.checks', self.__checks, value_prefix='check_')
        config += ValueMapper.parse_var('groups', self.__groups, value_prefix='hostgroup_')

        for custom_var in self.__custom_vars:
            config += '  vars.' + custom_var['key'] + ' = ' + ValueMapper.parse_value_for_var(
                custom_var['value']) + '\n'

        config += '  check_command = "hostalive"\n'
        config += '  zone = "' + self.__execution_zone.get_id() + '"\n'
        config += '}\n'

        return config



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.MonitoringPlugins.POPCommand import POPCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckPOP(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckPOP', 'pop')
        self.__host = None
        self.__port = None
        self.__ipv4 = False
        self.__ipv6 = False
        self.__escape = False
        self.__send = None
        self.__expect = None
        self.__all = False
        self.__quit = None
        self.__refuse_state = None
        self.__mismatch_state = None
        self.__jail = False
        self.__maxbytes = None
        self.__delay = None
        self.__cert_warning = 29
        self.__cert_critical = 15
        self.__cert = True
        self.__use_ssl = False
        self.__sni = None
        self.__warning_time = None
        self.__critical_time = None
        self.__timeout = 10
        self.add_service_group(ServiceGroup.create('pop'))
        self.add_service_group(ServiceGroup.create('mail'))

    def set_host(self, host):
        ValueChecker.is_string(host)
        self.__host = host
        return self

    def get_host(self):
        return self.__host

    def set_port(self, port):
        ValueChecker.is_number(port)
        self.__port = port
        return self

    def get_port(self):
        return self.__port

    def set_ipv4(self, ipv4):
        ValueChecker.is_bool(ipv4)
        self.__ipv4 = ipv4
        return self

    def get_ipv4(self):
        return self.__ipv4

    def set_ipv6(self, ipv6):
        ValueChecker.is_bool(ipv6)
        self.__ipv6 = ipv6
        return self

    def get_ipv6(self):
        return self.__ipv6

    def set_escape(self, escape):
        ValueChecker.is_bool(escape)
        self.__escape = escape
        return self

    def get_escape(self):
        return self.__escape

    def set_send(self, send):
        ValueChecker.is_string(send)
        self.__send = send
        return self

    def get_send(self):
        return self.__send

    def set_expect(self, expect):
        ValueChecker.is_string(expect)
        self.__expect = expect
        return self

    def get_expect(self):
        return self.__expect

    def set_all(self, all):
        ValueChecker.is_bool(all)
        self.__all = all
        return self

    def get_all(self):
        return self.__all

    def set_quit(self, quit):
        ValueChecker.is_string(quit)
        self.__quit = quit
        return self

    def get_quit(self):
        return self.__quit

    def set_refuse_state(self, refuse_state):
        ValueChecker.is_string(refuse_state)
        self.__refuse_state = refuse_state
        return self

    def get_refuse_state(self):
        return self.__refuse_state

    def set_mismatch_state(self, mismatch_state):
        ValueChecker.is_string(mismatch_state)
        self.__mismatch_state = mismatch_state
        return self

    def get_mismatch_state(self):
        return self.__mismatch_state

    def set_jail(self, jail):
        ValueChecker.is_bool(jail)
        self.__jail = jail
        return self

    def get_jail(self):
        return self.__jail

    def set_maxbytes(self, maxbytes):
        ValueChecker.is_number(maxbytes)
        self.__maxbytes = maxbytes
        return self

    def get_maxbytes(self):
        return self.__maxbytes

    def set_delay(self, delay):
        ValueChecker.is_number(delay)
        self.__delay = delay
        return self

    def get_delay(self):
        return self.__delay

    def set_cert_warning(self, cert_warning):
        ValueChecker.is_number(cert_warning)
        self.__cert_warning = cert_warning
        return self

    def get_cert_warning(self):
        return self.__cert_warning

    def set_cert_critical(self, cert_critical):
        ValueChecker.is_number(cert_critical)
        self.__cert_critical = cert_critical
        return self

    def get_cert_critical(self):
        return self.__cert_critical

    def set_cert(self, cert):
        ValueChecker.is_bool(cert)
        self.__cert = cert
        return self

    def get_cert(self):
        return self.__cert

    def set_use_ssl(self, use_ssl):
        ValueChecker.is_bool(use_ssl)
        self.__use_ssl = use_ssl
        return self

    def get_use_ssl(self):
        return self.__use_ssl

    def set_sni(self, sni):
        ValueChecker.is_string(sni)
        self.__sni = sni
        return self

    def get_sni(self):
        return self.__sni

    def set_warning_time(self, warning_time):
        ValueChecker.is_number(warning_time)
        self.__warning_time = warning_time
        return self

    def get_warning_time(self):
        return self.__warning_time

    def set_critical_time(self, critical_time):
        ValueChecker.is_number(critical_time)
        self.__critical_time = critical_time
        return self

    def get_critical_time(self):
        return self.__critical_time

    def set_timeout(self, timeout):
        ValueChecker.is_number(timeout)
        self.__timeout = timeout
        return self

    def get_timeout(self):
        return self.__timeout

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckPOP(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('pop'):
            POPCommand.create('pop')

        return check

    def validate(self):
        if None is self.__host:
            raise Exception('You have to specify a host for ' + self.get_id())
        if None is self.__port:
            raise Exception('You have to specify a port for ' + self.get_id())



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.ValueChecker import ValueChecker


class Application:

    def __init__(self):
        self.__enable_notifications = True
        self.__enable_event_handlers = True
        self.__enable_flapping = True
        self.__enable_host_checks = True
        self.__enable_service_checks = True
        self.__enable_perfdata = True
        self.__vars = []
        self.__environment = ''

    @staticmethod
    def create():
        return Application()

    def set_enable_notifications(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__enable_notifications = enabled
        return self

    def get_enable_notifications(self):
        return self.__enable_notifications

    def set_enable_event_handlers(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__enable_event_handlers = enabled
        return self

    def get_enable_event_handlers(self):
        return self.__enable_event_handlers

    def set_enable_flapping(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__enable_flapping = enabled
        return self

    def get_enable_flapping(self):
        return self.__enable_flapping

    def set_enable_host_checks(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__enable_host_checks = enabled
        return self

    def get_enable_host_checks(self):
        return self.__enable_host_checks

    def set_enable_service_checks(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__enable_service_checks = enabled
        return self

    def get_enable_service_checks(self):
        return self.__enable_service_checks

    def set_enable_perfdata(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__enable_perfdata = enabled
        return self

    def get_enable_perfdata(self):
        return self.__enable_perfdata

    def set_environment(self, env):
        ValueChecker.is_string(env)
        self.__environment = env
        return self

    def get_environment(self):
        return self.__environment

    def add_var(self, key, value):
        ValueChecker.is_string(key)
        ValueChecker.is_string(value)
        self.__vars.append((key, value))
        return self

    def get_config(self):
        config = 'object IcingaApplication "app" {\n'

        if True is self.__enable_notifications:
            config += '  enable_notifications = true\n'
        else:
            config += '  enable_notifications = false\n'

        if True is self.__enable_event_handlers:
            config += '  enable_event_handlers = true\n'
        else:
            config += '  enable_event_handlers = false\n'

        if True is self.__enable_flapping:
            config += '  enable_flapping = true\n'
        else:
            config += '  enable_flapping = false\n'

        if True is self.__enable_host_checks:
            config += '  enable_host_checks = true\n'
        else:
            config += '  enable_host_checks = false\n'

        if True is self.__enable_service_checks:
            config += '  enable_service_checks = true\n'
        else:
            config += '  enable_service_checks = false\n'

        if True is self.__enable_perfdata:
            config += '  enable_perfdata = true\n'
        else:
            config += '  enable_perfdata = false\n'

        config += '  environment = "' + self.__environment + '"\n'

        for var in self.__vars:
            if isinstance(var[1], str):
                config += '  vars.' + var[0] + ' = "' + var[1] + '"\n'
            elif isinstance(var[1], bool) and var[1]:
                config += '  vars.' + var[0] + ' = true\n'
            elif isinstance(var[1], bool) and not var[1]:
                config += '  vars.' + var[0] + ' = false\n'
            elif isinstance(var[1], float) or isinstance(var[1], int):
                config += '  vars.' + var[0] + ' = ' + str(var[1]) + '\n'

            else:
                raise Exception('Value of given var "' + var[0] + '" is currently not supported.')

        config += '}\n'

        return config



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.
from icinga2confgen.Checks.Icinga2Confgen.CheckDenyTlsVersion import CheckDenyTlsVersion
from icinga2confgen.Checks.MonitoringPlugins.CheckDummy import CheckDummy
from icinga2confgen.Checks.MonitoringPlugins.CheckHttp import CheckHttp
from icinga2confgen.Groups.HostGroup import HostGroup
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker
from icinga2confgen.ValueMapper import ValueMapper


class DefaultWebserverChecks:

    def __init__(self, vhostconfig=[], servers=[], checkserver=[], notifications=[]):
        self.__checkserver = checkserver
        self.__notifications = notifications
        self.__servers = servers
        self.__vhostconfigs = vhostconfig
        self.__validate_certificate = True
        self.__validate_http_redirect = True
        self.__warn_no_http_redirect = True
        self.__validate_allow_tls1 = False
        self.__validate_deny_tls1 = True
        self.__validate_allow_tls1_1 = False
        self.__validate_deny_tls1_1 = True
        self.__validate_allow_tls1_2 = True
        self.__validate_deny_tls1_2 = False
        self.__validate_allow_tls1_3 = True
        self.__validate_deny_tls1_3 = False
        self.__sni = True

    def get_vhostconfigs(self):
        return self.__vhostconfigs

    def get_servers(self):
        return self.__servers

    def get_checkservers(self):
        return self.__checkserver

    def validate_certificate(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_certificate = enabled

        return self

    def is_validating_certificate(self):
        return self.__validate_certificate

    def validate_http_redirect(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_http_redirect = enabled

        return self

    def is_validating_http_redirect(self):
        return self.__validate_http_redirect

    def warn_no_http_redirect(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__warn_no_http_redirect = enabled

        return self

    def is_warn_no_http_redirect(self):
        return self.__warn_no_http_redirect

    def validate_allow_tls1(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_allow_tls1 = enabled

        return self

    def is_validating_allow_tls1(self):
        return self.__validate_allow_tls1

    def validate_deny_tls1(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_tls1 = enabled

        return self

    def is_validating_deny_tls1(self):
        ValueChecker.is_bool(enabled)
        return self.__validate_deny_tls1

    def validate_allow_tls1_1(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_allow_tls1_1 = enabled

        return self

    def is_validating_allow_tls1_1(self):
        return self.__validate_allow_tls1_1

    def validate_deny_tls1_1(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_tls1_1 = enabled

        return self

    def is_validating_deny_tls1_1(self):
        return self.__validate_deny_tls1_1

    def validate_allow_tls1_2(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_allow_tls1_2 = enabled

        return self

    def is_validating_allow_tls1_2(self):
        return self.__validate_allow_tls1_2

    def validate_deny_tls1_2(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_tls1_2 = enabled

        return self

    def is_validating_deny_tls1_2(self):
        return self.__validate_deny_tls1_2

    def validate_allow_tls1_3(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_allow_tls1_3 = enabled

        return self

    def is_validating_allow_tls1_3(self):
        return self.__validate_allow_tls1_3

    def validate_deny_tls1_3(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_tls1_3 = enabled

        return self

    def is_validating_deny_tls1_3(self):
        return self.__validate_deny_tls1_3

    def set_sni(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__sni = enabled

        return self

    def get_sni(self):
        return self.__sni

    def apply_notification_to_check(self, check):
        for notification in self.__notifications:
            check.add_notification(notification)

    def apply(self):
        for config in self.__vhostconfigs:
            service_baseid = config[0]
            domain = config[1]
            uri = config[2]

            for checkserver in self.__checkserver:
                for server in self.__servers:
                    base_id = service_baseid + '_' + server.get_id() + '_' + ValueMapper.canonicalize_for_id(domain)
                    server_ipv4 = server.get_ipv4()
                    server_ipv6 = server.get_ipv6()

                    if None is server_ipv4 and None is server_ipv6:
                        raise Exception('It is required to set the ipv4 or ipv6 on the server with id "' +
                                        server.get_id() + '", before you can apply this checks!')

                    server.add_hostgroup(HostGroup.create('webserver'))

                    if None is not server_ipv4:
                        http_check = CheckHttp.create('web_access_default_ipv4_' + base_id)
                        http_check.set_ip(server_ipv4) \
                            .set_vhost(domain) \
                            .set_uri(uri) \
                            .set_ssl(True) \
                            .set_sni(self.__sni) \
                            .set_display_name(http_check.get_display_name() + ' ' + domain)
                        self.apply_notification_to_check(http_check)
                        checkserver.add_check(http_check)
                    if None is not server_ipv6:
                        http_check = CheckHttp.create('web_access_default_ipv6_' + base_id)
                        http_check.set_ip(server_ipv6) \
                            .set_vhost(domain) \
                            .set_uri(uri) \
                            .set_ssl(True) \
                            .set_sni(self.__sni) \
                            .set_display_name(http_check.get_display_name() + ' ' + domain)
                        self.apply_notification_to_check(http_check)
                        checkserver.add_check(http_check)

                    if True is self.__validate_certificate:
                        if None is not server_ipv4:
                            certificate_check = CheckHttp.create('web_access_certificate_ipv4_' + base_id)
                            certificate_check.set_ip(server_ipv4) \
                                .set_vhost(domain) \
                                .set_uri(uri) \
                                .set_ssl(True) \
                                .set_sni(self.__sni) \
                                .set_certificate_check(True) \
                                .set_check_interval('3h') \
                                .add_service_group(ServiceGroup.create('certificate_check')) \
                                .set_display_name(certificate_check.get_display_name() + ' ' + domain)
                            self.apply_notification_to_check(certificate_check)
                            checkserver.add_check(certificate_check)
                        if None is not server_ipv6:
                            certificate_check = CheckHttp.create('web_access_certificate_ipv6_' + base_id)
                            certificate_check.set_ip(server_ipv6) \
                                .set_vhost(domain) \
                                .set_uri(uri) \
                                .set_ssl(True) \
                                .set_sni(self.__sni) \
                                .set_certificate_check(True) \
                                .set_check_interval('3h') \
                                .add_service_group(ServiceGroup.create('certificate_check')) \
                                .set_display_name(certificate_check.get_display_name() + ' ' + domain)
                            self.apply_notification_to_check(certificate_check)

                            checkserver.add_check(certificate_check)
                    else:
                        server.add_hostgroup(HostGroup.create('no_certificate_check'))

                    if True is self.__validate_http_redirect:
                        if None is not server_ipv4:
                            redirect_check = CheckHttp.create('web_access_http_redirect_ipv4_' + base_id)
                            redirect_check.set_ip(server_ipv4) \
                                .set_vhost(domain) \
                                .set_uri(uri) \
                                .set_ssl(False) \
                                .set_sni(self.__sni) \
                                .set_port(80) \
                                .set_expect('HTTP/1.1 30') \
                                .set_check_interval('6h') \
                                .add_service_group(ServiceGroup.create('http_redirect')) \
                                .set_display_name(redirect_check.get_display_name() + ' ' + domain)
                            self.apply_notification_to_check(redirect_check)
                            checkserver.add_check(redirect_check)

                        if None is not server_ipv6:
                            redirect_check = CheckHttp.create('web_access_http_redirect_ipv6_' + base_id)
                            redirect_check.set_ip(server_ipv6) \
                                .set_vhost(domain) \
                                .set_uri(uri) \
                                .set_ssl(False) \
                                .set_sni(self.__sni) \
                                .set_port(80) \
                                .set_expect('HTTP/1.1 30') \
                                .set_check_interval('6h') \
                                .add_service_group(ServiceGroup.create('http_redirect')) \
                                .set_display_name(redirect_check.get_display_name() + ' ' + domain)
                            self.apply_notification_to_check(redirect_check)
                            checkserver.add_check(redirect_check)

                        server.add_hostgroup(HostGroup.create('http_redirect'))

                    elif True is self.__warn_no_http_redirect:
                        redirect_check = CheckDummy.create('web_access_missing_http_redirect_' + base_id)
                        redirect_check.set_state(1) \
                            .set_text(redirect_check.get_display_name() + ' ' + domain) \
                            .set_check_interval('6h') \
                            .add_service_group(ServiceGroup.create('missing_http_redirect_check')) \
                            .set_display_name(redirect_check.get_display_name() + ' ' + domain)

                        checkserver.add_check(redirect_check)
                        self.apply_notification_to_check(redirect_check)
                        server.add_hostgroup(HostGroup.create('no_http_redirect'))

                    else:
                        server.add_hostgroup(HostGroup.create('http_redirect_unchecked'))

                    if True is self.__validate_allow_tls1:
                        if None is not server_ipv4:
                            tls1_check = CheckHttp.create('web_access_allow_tls1_ipv4_' + base_id)
                            tls1_check.set_ip(server_ipv4) \
                                .set_vhost(domain) \
                                .set_uri(uri) \
                                .set_sni(self.__sni) \
                                .set_ssl_protocol('1.1') \
                                .set_check_interval('6h') \
                                .add_service_group(ServiceGroup.create('tls_1_check')) \
                                .set_display_name(tls1_check.get_display_name() + ' ' + domain)
                            self.apply_notification_to_check(tls1_check)
                            checkserver.add_check(tls1_check)

                        if None is not server_ipv6:
                            tls1_check = CheckHttp.create('web_access_allow_tls1_ipv6_' + base_id)
                            tls1_check.set_ip(server_ipv6) \
                                .set_vhost(domain) \
                                .set_uri(uri) \
                                .set_sni(self.__sni) \
                                .set_ssl_protocol('1.1') \
                                .set_check_interval('6h') \
                                .add_service_group(ServiceGroup.create('tls_1_check')) \
                                .set_display_name(tls1_check.get_display_name() + ' ' + domain)
                            self.apply_notification_to_check(tls1_check)
                            checkserver.add_check(tls1_check)

                        server.add_hostgroup(HostGroup.create('insecure_webserver'))
                        server.add_hostgroup(HostGroup.create('insecure_TLSv1_0_Webserver'))
                    elif True is self.__validate_deny_tls1:
                        if None is not server_ipv4:
                            tls1_check = CheckDenyTlsVersion.create('web_access_deny_tls1_ipv4_' + base_id)
                            tls1_check.set_address(server_ipv4) \
                                .set_domain(domain) \
                                .set_protocol('1.0') \
                                .set_check_interval('6h') \
                                .add_service_group(ServiceGroup.create('tls_1_check')) \
                                .set_display_name(tls1_check.get_display_name() + ' ' + domain)
                            self.apply_notification_to_check(tls1_check)
                            checkserver.add_check(tls1_check)

                        if None is not server_ipv6:
                            tls1_check = CheckDenyTlsVersion.create('web_access_deny_tls1_ipv6_' + base_id)
                            tls1_check.set_address(server_ipv6) \
                                .set_domain(domain) \
                                .set_protocol('1.0') \
                                .set_check_interval('6h') \
                                .add_service_group(ServiceGroup.create('tls_1_check')) \
                                .set_display_name(tls1_check.get_display_name() + ' ' + domain)
                            self.apply_notification_to_check(tls1_check)
                            checkserver.add_check(tls1_check)

                        server.add_hostgroup(HostGroup.create('deny_insecure_TLSv1_0_webserver'))
                    else:
                        server.add_hostgroup(HostGroup.create('deny_insecure_TLSv1_0_unchecked'))

                    if True is self.__validate_allow_tls1_1:
                        if None is not server_ipv4:
                            tls1_1_check = CheckHttp.create('web_access_allow_tls1_1_ipv4_' + base_id)
                            tls1_1_check.set_vhost(domain) \
                                .set_ip(server_ipv4) \
                                .set_uri(uri) \
                                .set_sni(self.__sni) \
                                .set_ssl_protocol('1.1') \
                                .set_check_interval('6h') \
                                .add_service_group(ServiceGroup.create('tls_1_1_check')) \
                                .set_display_name(tls1_1_check.get_display_name() + ' ' + domain)
                            self.apply_notification_to_check(tls1_1_check)
                            checkserver.add_check(tls1_1_check)

                        if None is not server_ipv6:
                            tls1_1_check = CheckHttp.create('web_access_allow_tls1_1_ipv6_' + base_id)
                            tls1_1_check.set_vhost(domain) \
                                .set_ip(server_ipv6) \
                                .set_uri(uri) \
                                .set_sni(self.__sni) \
                                .set_ssl_protocol('1.1') \
                                .set_check_interval('6h') \
                                .add_service_group(ServiceGroup.create('tls_1_1_check')) \
                                .set_display_name(tls1_1_check.get_display_name() + ' ' + domain)
                            self.apply_notification_to_check(tls1_1_check)
                            checkserver.add_check(tls1_1_check)

                        server.add_hostgroup(HostGroup.create('insecure_webserver'))
                        server.add_hostgroup(HostGroup.create('insecure_TLSv1_1_webserver'))

                    elif True is self.__validate_deny_tls1_1:
                        if None is not server_ipv4:
                            tls1_1_check = CheckDenyTlsVersion.create('web_access_deny_tls1_1_ipv4_' + base_id)
                            tls1_1_check.set_address(server_ipv4) \
                                .set_domain(domain) \
                                .set_protocol('1.1') \
                                .set_check_interval('6h') \
                                .add_service_group(ServiceGroup.create('tls_1_1_check')) \
                                .set_display_name(tls1_1_check.get_display_name() + ' ' + domain)
                            self.apply_notification_to_check(tls1_1_check)
                            checkserver.add_check(tls1_1_check)

                        if None is not server_ipv6:
                            tls1_1_check = CheckDenyTlsVersion.create('web_access_deny_tls1_1_ipv6_' + base_id)
                            tls1_1_check.set_address(server_ipv6) \
                                .set_domain(domain) \
                                .set_protocol('1.1') \
                                .set_check_interval('6h') \
                                .add_service_group(ServiceGroup.create('tls_1_1_check')) \
                                .set_display_name(tls1_1_check.get_display_name() + ' ' + domain)
                            self.apply_notification_to_check(tls1_1_check)
                            checkserver.add_check(tls1_1_check)

                        server.add_hostgroup(HostGroup.create('deny_insecure_TLSv1_1_Webserver'))
                    else:
                        server.add_hostgroup(HostGroup.create('deny_insecure_TLSv1_1_unchecked'))

                    if True is self.__validate_allow_tls1_2:
                        if None is not server_ipv4:
                            tls1_2_check = CheckHttp.create('web_access_allow_tls1_2_ipv4_' + base_id)
                            tls1_2_check.set_vhost(domain) \
                                .set_ip(server_ipv4) \
                                .set_uri(uri) \
                                .set_sni(self.__sni) \
                                .set_ssl_protocol('1.2') \
                                .set_check_interval('6h') \
                                .add_service_group(ServiceGroup.create('tls_1_2_check')) \
                                .set_display_name(tls1_2_check.get_display_name() + ' ' + domain)

                            self.apply_notification_to_check(tls1_2_check)
                            checkserver.add_check(tls1_2_check)

                        if None is not server_ipv6:
                            tls1_2_check = CheckHttp.create('web_access_allow_tls1_2_ipv6_' + base_id)
                            tls1_2_check.set_vhost(domain) \
                                .set_ip(server_ipv6) \
                                .set_uri(uri) \
                                .set_sni(self.__sni) \
                                .set_ssl_protocol('1.2') \
                                .set_check_interval('6h') \
                                .add_service_group(ServiceGroup.create('tls_1_2_check')) \
                                .set_display_name(tls1_2_check.get_display_name() + ' ' + domain)

                            self.apply_notification_to_check(tls1_2_check)
                            checkserver.add_check(tls1_2_check)

                        server.add_hostgroup(HostGroup.create('secure_webserver'))
                        server.add_hostgroup(HostGroup.create('secure_TLSv1_2_webserver'))

                    elif True is self.__validate_deny_tls1_2:
                        if None is not server_ipv4:
                            tls1_2_check = CheckDenyTlsVersion.create('web_access_deny_tls1_2_ipv4_' + base_id)
                            tls1_2_check.set_address(server_ipv4) \
                                .set_domain(domain) \
                                .set_protocol('1.2') \
                                .set_check_interval('6h') \
                                .add_service_group(ServiceGroup.create('tls_1_2_check')) \
                                .set_display_name(tls1_2_check.get_display_name() + ' ' + domain)
                            self.apply_notification_to_check(tls1_2_check)
                            checkserver.add_check(tls1_2_check)

                        if None is not server_ipv6:
                            tls1_2_check = CheckDenyTlsVersion.create('web_access_deny_tls1_2_ipv6_' + base_id)
                            tls1_2_check.set_address(server_ipv6) \
                                .set_domain(domain) \
                                .set_protocol('1.2') \
                                .set_check_interval('6h') \
                                .add_service_group(ServiceGroup.create('tls_1_2_check')) \
                                .set_display_name(tls1_2_check.get_display_name() + ' ' + domain)
                            self.apply_notification_to_check(tls1_2_check)
                            checkserver.add_check(tls1_2_check)

                        server.add_hostgroup(HostGroup.create('insecure_webserver'))
                        server.add_hostgroup(HostGroup.create('deny_secure_TLSv1_2_webserver'))


                    else:
                        server.add_hostgroup(HostGroup.create('secure_TLSv1_2_unchecked'))

                    if True is self.__validate_allow_tls1_3:
                        if None is not server_ipv4:
                            tls1_3_check = CheckHttp.create('web_access_allow_tls1_3_ipv4_' + base_id)
                            tls1_3_check.set_ip(server_ipv4) \
                                .set_vhost(domain) \
                                .set_uri(uri) \
                                .set_sni(self.__sni) \
                                .set_ssl_protocol('1.3') \
                                .set_check_interval('6h') \
                                .add_service_group(ServiceGroup.create('tls_1_3_check')) \
                                .set_display_name(tls1_3_check.get_display_name() + ' ' + domain)

                            self.apply_notification_to_check(tls1_3_check)
                            checkserver.add_check(tls1_3_check)

                        if None is not server_ipv6:
                            tls1_3_check = CheckHttp.create('web_access_allow_tls1_3_ipv6_' + base_id)
                            tls1_3_check.set_ip(server_ipv6) \
                                .set_vhost(domain) \
                                .set_uri(uri) \
                                .set_sni(self.__sni) \
                                .set_ssl_protocol('1.3') \
                                .set_check_interval('6h') \
                                .add_service_group(ServiceGroup.create('tls_1_3_check')) \
                                .set_display_name(tls1_3_check.get_display_name() + ' ' + domain)

                            self.apply_notification_to_check(tls1_3_check)
                            checkserver.add_check(tls1_3_check)

                        server.add_hostgroup(HostGroup.create('secure_webserver'))
                        server.add_hostgroup(HostGroup.create('secure_TLSv1_3_Webserver'))

                    elif True is self.__validate_deny_tls1_3:
                        if None is not server_ipv4:
                            tls1_3_check = CheckDenyTlsVersion.create('web_access_deny_tls1_2_ipv4_' + base_id)
                            tls1_3_check.set_address(server_ipv4) \
                                .set_domain(domain) \
                                .set_protocol('1.3') \
                                .set_check_interval('6h') \
                                .add_service_group(ServiceGroup.create('tls_1_3_check')) \
                                .set_display_name(tls1_3_check.get_display_name() + ' ' + domain)

                            self.apply_notification_to_check(tls1_3_check)
                            checkserver.add_check(tls1_3_check)

                        if None is not server_ipv6:
                            tls1_3_check = CheckDenyTlsVersion.create('web_access_deny_tls1_2_ipv6_' + base_id)
                            tls1_3_check.set_address(server_ipv6) \
                                .set_domain(domain) \
                                .set_protocol('1.3') \
                                .set_check_interval('6h') \
                                .add_service_group(ServiceGroup.create('tls_1_3_check')) \
                                .set_display_name(tls1_3_check.get_display_name() + ' ' + domain)

                            self.apply_notification_to_check(tls1_3_check)
                            checkserver.add_check(tls1_3_check)

                        server.add_hostgroup(HostGroup.create('insecure_webserver'))
                        server.add_hostgroup(HostGroup.create('deny_secure_TLSv1_3_webserver'))
                    else:
                        server.add_hostgroup(HostGroup.create('secure_TLSv1_3_unchecked'))
